@@ -467,8 +467,8 @@ void OCalcTable::fillColumns()
     String aStrFieldName;
     aStrFieldName.AssignAscii("Column");
     ::rtl::OUString aTypeName;
-    ::comphelper::UStringMixEqual aCase(m_pConnection->getMetaData()->storesMixedCaseQuotedIdentifiers());
-    const sal_Bool bStoresMixedCaseQuotedIdentifiers = getConnection()->getMetaData()->storesMixedCaseQuotedIdentifiers();
+    ::comphelper::UStringMixEqual aCase(m_pConnection->getMetaData()->supportsMixedCaseQuotedIdentifiers());
+    const sal_Bool bStoresMixedCaseQuotedIdentifiers = getConnection()->getMetaData()->supportsMixedCaseQuotedIdentifiers();
 
     for (sal_Int32 i = 0; i < m_nDataCols; i++)
     {
@@ -494,22 +494,22 @@ void OCalcTable::fillColumns()
                 }
                 break;
             case DataType::DECIMAL:
-                aTypeName = ::rtl::OUString::createFromAscii("DECIMAL");
+                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DECIMAL"));
                 break;
             case DataType::BIT:
-                aTypeName = ::rtl::OUString::createFromAscii("BOOL");
+                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("BOOL"));
                 break;
             case DataType::DATE:
-                aTypeName = ::rtl::OUString::createFromAscii("DATE");
+                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DATE"));
                 break;
             case DataType::TIME:
-                aTypeName = ::rtl::OUString::createFromAscii("TIME");
+                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TIME"));
                 break;
             case DataType::TIMESTAMP:
-                aTypeName = ::rtl::OUString::createFromAscii("TIMESTAMP");
+                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TIMESTAMP"));
                 break;
             default:
-                OSL_ASSERT("missing type name");
+                OSL_FAIL("missing type name");
                 aTypeName = ::rtl::OUString();
         }
 
@@ -826,12 +826,12 @@ sal_Bool OCalcTable::fetchRow( OValueRefRow& _rRow, const OSQLColumns & _rCols,
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "calc", "Ocke.Janssen@sun.com", "OCalcTable::fetchRow" );
     // read the bookmark
 
-    BOOL bIsCurRecordDeleted = sal_False;
+    sal_Bool bIsCurRecordDeleted = sal_False;
     _rRow->setDeleted(bIsCurRecordDeleted);
     *(_rRow->get())[0] = m_nFilePos;
 
     if (!bRetrieveData)
-        return TRUE;
+        return sal_True;
 
     // fields
 
