@@ -44,17 +44,11 @@ void ImpEditEngine::SetStyleSheetPool( SfxStyleSheetPool* pSPool )
 {
     if ( pStylePool != pSPool )
     {
-//		if ( pStylePool )
-//			EndListening( *pStylePool, TRUE );
-
         pStylePool = pSPool;
-
-//		if ( pStylePool )
-//			StartListening( *pStylePool, TRUE );
     }
 }
 
-SfxStyleSheet* ImpEditEngine::GetStyleSheet( USHORT nPara ) const
+SfxStyleSheet* ImpEditEngine::GetStyleSheet( sal_uInt16 nPara ) const
 {
     ContentNode* pNode = aEditDoc.SaveGetObject( nPara );
     return pNode ? pNode->GetContentAttribs().GetStyleSheet() : NULL;
@@ -64,19 +58,19 @@ void ImpEditEngine::SetStyleSheet( EditSelection aSel, SfxStyleSheet* pStyle )
 {
     aSel.Adjust( aEditDoc );
 
-    USHORT nStartPara = aEditDoc.GetPos( aSel.Min().GetNode() );
-    USHORT nEndPara = aEditDoc.GetPos( aSel.Max().GetNode() );
+    sal_uInt16 nStartPara = aEditDoc.GetPos( aSel.Min().GetNode() );
+    sal_uInt16 nEndPara = aEditDoc.GetPos( aSel.Max().GetNode() );
 
-    BOOL _bUpdate = GetUpdateMode();
-    SetUpdateMode( FALSE );
+    sal_Bool _bUpdate = GetUpdateMode();
+    SetUpdateMode( sal_False );
 
-    for ( USHORT n = nStartPara; n <= nEndPara; n++ )
+    for ( sal_uInt16 n = nStartPara; n <= nEndPara; n++ )
         SetStyleSheet( n, pStyle );
 
     SetUpdateMode( _bUpdate, 0 );
 }
 
-void ImpEditEngine::SetStyleSheet( USHORT nPara, SfxStyleSheet* pStyle )
+void ImpEditEngine::SetStyleSheet( sal_uInt16 nPara, SfxStyleSheet* pStyle )
 {
     DBG_ASSERT( GetStyleSheetPool() || !pStyle, "SetStyleSheet: No StyleSheetPool registered!" );
     ContentNode* pNode = aEditDoc.SaveGetObject( nPara );
@@ -100,10 +94,10 @@ void ImpEditEngine::SetStyleSheet( USHORT nPara, SfxStyleSheet* pStyle )
                         pNode->GetContentAttribs().GetItems() ) );
         }
         if ( pCurStyle )
-            EndListening( *pCurStyle, FALSE );
+            EndListening( *pCurStyle, sal_False );
         pNode->SetStyleSheet( pStyle, aStatus.UseCharAttribs() );
         if ( pStyle )
-            StartListening( *pStyle, FALSE );
+            StartListening( *pStyle, sal_False );
         ParaAttribsChanged( pNode );
     }
     FormatAndUpdate();
@@ -114,17 +108,17 @@ void ImpEditEngine::UpdateParagraphsWithStyleSheet( SfxStyleSheet* pStyle )
     SvxFont aFontFromStyle;
     CreateFont( aFontFromStyle, pStyle->GetItemSet() );
 
-    BOOL bUsed = FALSE;
-    for ( USHORT nNode = 0; nNode < aEditDoc.Count(); nNode++ )
+    sal_Bool bUsed = sal_False;
+    for ( sal_uInt16 nNode = 0; nNode < aEditDoc.Count(); nNode++ )
     {
         ContentNode* pNode = aEditDoc.GetObject( nNode );
         if ( pNode->GetStyleSheet() == pStyle )
         {
-            bUsed = TRUE;
+            bUsed = sal_True;
             if ( aStatus.UseCharAttribs() )
                 pNode->SetStyleSheet( pStyle, aFontFromStyle );
             else
-                pNode->SetStyleSheet( pStyle, FALSE );
+                pNode->SetStyleSheet( pStyle, sal_False );
 
             ParaAttribsChanged( pNode );
         }
@@ -138,7 +132,7 @@ void ImpEditEngine::UpdateParagraphsWithStyleSheet( SfxStyleSheet* pStyle )
 
 void ImpEditEngine::RemoveStyleFromParagraphs( SfxStyleSheet* pStyle )
 {
-    for ( USHORT nNode = 0; nNode < aEditDoc.Count(); nNode++ )
+    for ( sal_uInt16 nNode = 0; nNode < aEditDoc.Count(); nNode++ )
     {
         ContentNode* pNode = aEditDoc.GetObject(nNode);
         if ( pNode->GetStyleSheet() == pStyle )
@@ -152,18 +146,18 @@ void ImpEditEngine::RemoveStyleFromParagraphs( SfxStyleSheet* pStyle )
 
 void ImpEditEngine::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
 {
-    // Damit nicht beim Destruieren unnoetig formatiert wird:
+    // So that not a lot of unnecessary formatting is done when destructing:
     if ( !bDowning )
     {
         DBG_CHKOBJ( GetEditEnginePtr(), EditEngine, 0 );
 
         SfxStyleSheet* pStyle = NULL;
-        ULONG nId = 0;
+        sal_uLong nId = 0;
 
         if ( rHint.ISA( SfxStyleSheetHint ) )
         {
             const SfxStyleSheetHint& rH = (const SfxStyleSheetHint&) rHint;
-            DBG_ASSERT( rH.GetStyleSheet()->ISA( SfxStyleSheet ), "Kein SfxStyleSheet!" );
+            DBG_ASSERT( rH.GetStyleSheet()->ISA( SfxStyleSheet ), "No SfxStyleSheet!" );
             pStyle = (SfxStyleSheet*) rH.GetStyleSheet();
             nId = rH.GetHint();
         }
@@ -185,17 +179,6 @@ void ImpEditEngine::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
                       ( nId == SFX_STYLESHEET_MODIFIED ) )
             {
                 UpdateParagraphsWithStyleSheet( pStyle );
-
-                // Alle Absaetze mit EditStyles, die das geaenderte Style
-                // irgendwie als Parent haben, muessen formatiert werden.
-                // ULONG nStyles = pMyStylePool->GetStyles().Count();
-                // for ( ULONG nStyle = 0; nStyle < nStyles; nStyle++ )
-                // {
-                // 	EditStyleSheet* pES = (EditStyleSheet*)pMyStylePool->GetStyles().GetObject( nStyle );
-                // 	DBG_ASSERT( pES, "NULL-Pointer im StyleSheetPool!" );
-                // 	if ( pES->IsUsed() && pES->HasStyleAsAnyParent( *pStyle ) )
-                // 		UpdateParagraphsWithStyleSheet( pES );
-                // }
             }
         }
     }
@@ -203,13 +186,13 @@ void ImpEditEngine::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
 
 EditUndoSetAttribs* ImpEditEngine::CreateAttribUndo( EditSelection aSel, const SfxItemSet& rSet )
 {
-    DBG_ASSERT( !aSel.DbgIsBuggy( aEditDoc ), "CreateAttribUndo: Fehlerhafte Selektion" );
+    DBG_ASSERT( !aSel.DbgIsBuggy( aEditDoc ), "CreateAttribUndo: Incorrect selection ");
     aSel.Adjust( aEditDoc );
 
     ESelection aESel( CreateESel( aSel ) );
 
-    USHORT nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
-    USHORT nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
+    sal_uInt16 nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
+    sal_uInt16 nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
 
     DBG_ASSERT( nStartNode <= nEndNode, "CreateAttribUndo: Start > End ?!" );
 
@@ -227,14 +210,14 @@ EditUndoSetAttribs* ImpEditEngine::CreateAttribUndo( EditSelection aSel, const S
 
     SfxItemPool* pPool = pUndo->GetNewAttribs().GetPool();
 
-    for ( USHORT nPara = nStartNode; nPara <= nEndNode; nPara++ )
+    for ( sal_uInt16 nPara = nStartNode; nPara <= nEndNode; nPara++ )
     {
         ContentNode* pNode = aEditDoc.GetObject( nPara );
-        DBG_ASSERT( aEditDoc.SaveGetObject( nPara ), "Node nicht gefunden: CreateAttribUndo" );
+        DBG_ASSERT( aEditDoc.SaveGetObject( nPara ), "Node not found: CreateAttribUndo" );
         ContentAttribsInfo* pInf = new ContentAttribsInfo( pNode->GetContentAttribs().GetItems() );
         pUndo->GetContentInfos().Insert( pInf, pUndo->GetContentInfos().Count() );
 
-        for ( USHORT nAttr = 0; nAttr < pNode->GetCharAttribs().Count(); nAttr++ )
+        for ( sal_uInt16 nAttr = 0; nAttr < pNode->GetCharAttribs().Count(); nAttr++ )
         {
             EditCharAttribPtr pAttr = pNode->GetCharAttribs().GetAttribs()[ nAttr ];
             if ( pAttr->GetLen() )
@@ -247,7 +230,7 @@ EditUndoSetAttribs* ImpEditEngine::CreateAttribUndo( EditSelection aSel, const S
     return pUndo;
 }
 
-void ImpEditEngine::UndoActionStart( USHORT nId, const ESelection& aSel )
+void ImpEditEngine::UndoActionStart( sal_uInt16 nId, const ESelection& aSel )
 {
     if ( IsUndoEnabled() && !IsInUndo() )
     {
@@ -257,7 +240,7 @@ void ImpEditEngine::UndoActionStart( USHORT nId, const ESelection& aSel )
     }
 }
 
-void ImpEditEngine::UndoActionStart( USHORT nId )
+void ImpEditEngine::UndoActionStart( sal_uInt16 nId )
 {
     if ( IsUndoEnabled() && !IsInUndo() )
     {
@@ -266,7 +249,7 @@ void ImpEditEngine::UndoActionStart( USHORT nId )
     }
 }
 
-void ImpEditEngine::UndoActionEnd( USHORT )
+void ImpEditEngine::UndoActionEnd( sal_uInt16 )
 {
     if ( IsUndoEnabled() && !IsInUndo() )
     {
@@ -276,13 +259,13 @@ void ImpEditEngine::UndoActionEnd( USHORT )
     }
 }
 
-void ImpEditEngine::InsertUndo( EditUndo* pUndo, BOOL bTryMerge )
+void ImpEditEngine::InsertUndo( EditUndo* pUndo, sal_Bool bTryMerge )
 {
-    DBG_ASSERT( !IsInUndo(), "InsertUndo im Undomodus!" );
+    DBG_ASSERT( !IsInUndo(), "InsertUndo in Undomodus!" );
     if ( pUndoMarkSelection )
     {
         EditUndoMarkSelection* pU = new EditUndoMarkSelection( this, *pUndoMarkSelection );
-        GetUndoManager().AddUndoAction( pU, FALSE );
+        GetUndoManager().AddUndoAction( pU, sal_False );
         delete pUndoMarkSelection;
         pUndoMarkSelection = NULL;
     }
@@ -297,90 +280,83 @@ void ImpEditEngine::ResetUndoManager()
         GetUndoManager().Clear();
 }
 
-void ImpEditEngine::EnableUndo( BOOL bEnable )
+void ImpEditEngine::EnableUndo( sal_Bool bEnable )
 {
-    // Beim Umschalten des Modus Liste loeschen:
+    // When switching the mode Delete list:
     if ( bEnable != IsUndoEnabled() )
         ResetUndoManager();
 
     bUndoEnabled = bEnable;
 }
 
-BOOL ImpEditEngine::Undo( EditView* pView )
+sal_Bool ImpEditEngine::Undo( EditView* pView )
 {
     if ( HasUndoManager() && GetUndoManager().GetUndoActionCount() )
     {
         SetActiveView( pView );
-        GetUndoManager().Undo( 1 );
-        return TRUE;
+        GetUndoManager().Undo();
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
-BOOL ImpEditEngine::Redo( EditView* pView )
+sal_Bool ImpEditEngine::Redo( EditView* pView )
 {
     if ( HasUndoManager() && GetUndoManager().GetRedoActionCount() )
     {
         SetActiveView( pView );
-        GetUndoManager().Redo( 0 );
-        return TRUE;
+        GetUndoManager().Redo();
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
-BOOL ImpEditEngine::Repeat( EditView* /* pView */ )
+sal_Bool ImpEditEngine::Repeat( EditView* /* pView */ )
 {
     if ( HasUndoManager() && GetUndoManager().GetRepeatActionCount() )
     {
-        DBG_WARNING( "Repeat nicht implementiert!" );
-        return TRUE;
+        DBG_WARNING( "Repeat not implemented!" );
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
-SfxItemSet ImpEditEngine::GetAttribs( EditSelection aSel, BOOL bOnlyHardAttrib )
+SfxItemSet ImpEditEngine::GetAttribs( EditSelection aSel, sal_Bool bOnlyHardAttrib )
 {
     DBG_CHKOBJ( GetEditEnginePtr(), EditEngine, 0 );
 
     aSel.Adjust( aEditDoc );
 
-#if OSL_DEBUG_LEVEL > 1
-//    if ( ( aSel.Min().GetNode() == aSel.Max().GetNode() ) && ( bOnlyHardAttrib == EditEngineAttribs_All ) )
-//        return GetAttribs( aEditDoc.GetPos( aSel.Min().GetNode() ), aSel.Min().GetIndex(), aSel.Max().GetIndex(), GETATTRIBS_ALL );
-#endif
-
-
     SfxItemSet aCurSet( GetEmptyItemSet() );
 
-    USHORT nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
-    USHORT nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
+    sal_uInt16 nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
+    sal_uInt16 nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
 
-    // ueber die Absaetze iterieren...
-    for ( USHORT nNode = nStartNode; nNode <= nEndNode; nNode++	)
+    // iterate over the paragraphs ...
+    for ( sal_uInt16 nNode = nStartNode; nNode <= nEndNode; nNode++	)
     {
         ContentNode* pNode = aEditDoc.GetObject( nNode );
-        DBG_ASSERT( aEditDoc.SaveGetObject( nNode ), "Node nicht gefunden: GetAttrib" );
+        DBG_ASSERT( aEditDoc.SaveGetObject( nNode ), "Node not found: GetAttrib" );
 
         xub_StrLen nStartPos = 0;
         xub_StrLen nEndPos = pNode->Len();
         if ( nNode == nStartNode )
             nStartPos = aSel.Min().GetIndex();
-        if ( nNode == nEndNode ) // kann auch == nStart sein!
+        if ( nNode == nEndNode ) // Can also be == nStart!
             nEndPos = aSel.Max().GetIndex();
 
-        // Problem: Vorlagen....
-        // => Andersrum:
-        // 1) Harte Zeichenattribute, wie gehabt...
-        // 2) Nur wenn OFF, Style and Absatzattr. pruefen...
+        // Problem: Templates ....
+        // =>  Other way:
+        // 1) Hard character attributes, as usual ...
+        // 2) Examine Style and paragraph attributes only when OFF ...
 
-        // Erst die ganz harte Formatierung...
+        // First the very hard formatting ...
         aEditDoc.FindAttribs( pNode, nStartPos, nEndPos, aCurSet );
 
         if( bOnlyHardAttrib != EditEngineAttribs_OnlyHard )
         {
-            // Und dann Absatzformatierung und Vorlage...
-            // SfxStyleSheet* pStyle = pNode->GetStyleSheet();
-            for ( USHORT nWhich = EE_ITEMS_START; nWhich <= EE_CHAR_END; nWhich++)
+            // and then paragraph formatting and template...
+            for ( sal_uInt16 nWhich = EE_ITEMS_START; nWhich <= EE_CHAR_END; nWhich++)
             {
                 if ( aCurSet.GetItemState( nWhich ) == SFX_ITEM_OFF )
                 {
@@ -409,13 +385,12 @@ SfxItemSet ImpEditEngine::GetAttribs( EditSelection aSel, BOOL bOnlyHardAttrib )
                     // pItem can only be NULL when bOnlyHardAttrib...
                     if ( !pItem || ( *pItem != aCurSet.Get( nWhich ) ) )
                     {
-                        // Problem: Wenn Absatzvorlage mit z.B. Font,
-                        // aber Font hart und anders und komplett in Selektion
-                        // Falsch, wenn invalidiert....
-                        // => Lieber nicht invalidieren, UMSTELLEN!
-                        // Besser waere, Absatzweise ein ItemSet zu fuellen
-                        // und dieses mit dem gesmten vergleichen.
-    //						aCurSet.InvalidateItem( nWhich );
+                        // Problem: When Paragraph style with for example font,
+                        // but the Font is hard and completely different, 
+                        // wrong in selection  if invalidated....
+                        // => better not invalidate, instead CHANGE!
+                        // It would be better to fill each paragraph with 
+                        // a itemset and compare this in large.
                         if ( nWhich <= EE_PARA_END )
                             aCurSet.InvalidateItem( nWhich );
                     }
@@ -424,10 +399,10 @@ SfxItemSet ImpEditEngine::GetAttribs( EditSelection aSel, BOOL bOnlyHardAttrib )
         }
     }
 
-    // Leere Slots mit Defaults fuellen...
+    // fill empty slots with defaults ...
     if ( bOnlyHardAttrib == EditEngineAttribs_All )
     {
-        for ( USHORT nWhich = EE_ITEMS_START; nWhich <= EE_CHAR_END; nWhich++ )
+        for ( sal_uInt16 nWhich = EE_ITEMS_START; nWhich <= EE_CHAR_END; nWhich++ )
         {
             if ( aCurSet.GetItemState( nWhich ) == SFX_ITEM_OFF )
             {
@@ -439,9 +414,9 @@ SfxItemSet ImpEditEngine::GetAttribs( EditSelection aSel, BOOL bOnlyHardAttrib )
 }
 
 
-SfxItemSet ImpEditEngine::GetAttribs( USHORT nPara, USHORT nStart, USHORT nEnd, sal_uInt8 nFlags ) const
+SfxItemSet ImpEditEngine::GetAttribs( sal_uInt16 nPara, sal_uInt16 nStart, sal_uInt16 nEnd, sal_uInt8 nFlags ) const
 {
-    // MT: #94002# Optimized function with less Puts(), which cause unnecessary cloning from default items.
+    // Optimized function with less Puts(), which cause unnecessary cloning from default items.
     // If this works, change GetAttribs( EditSelection ) to use this for each paragraph and merge the results!
 
     DBG_CHKOBJ( GetEditEnginePtr(), EditEngine, 0 );
@@ -463,7 +438,7 @@ SfxItemSet ImpEditEngine::GetAttribs( USHORT nPara, USHORT nStart, USHORT nEnd,
         // StyleSheet / Parattribs...
 
         if ( pNode->GetStyleSheet() && ( nFlags & GETATTRIBS_STYLESHEET ) )
-            aAttribs.Set( pNode->GetStyleSheet()->GetItemSet(), TRUE );
+            aAttribs.Set( pNode->GetStyleSheet()->GetItemSet(), sal_True );
 
         if ( nFlags & GETATTRIBS_PARAATTRIBS )
             aAttribs.Put( pNode->GetContentAttribs().GetItems() );
@@ -476,13 +451,13 @@ SfxItemSet ImpEditEngine::GetAttribs( USHORT nPara, USHORT nStart, USHORT nEnd,
             pNode->GetCharAttribs().OptimizeRanges( ((ImpEditEngine*)this)->GetEditDoc().GetItemPool() );
 
             const CharAttribArray& rAttrs = pNode->GetCharAttribs().GetAttribs();
-            for ( USHORT nAttr = 0; nAttr < rAttrs.Count(); nAttr++ )
+            for ( sal_uInt16 nAttr = 0; nAttr < rAttrs.Count(); nAttr++ )
             {
                 EditCharAttrib* pAttr = rAttrs.GetObject( nAttr );
 
                 if ( nStart == nEnd )
                 {
-                    USHORT nCursorPos = nStart;
+                    sal_uInt16 nCursorPos = nStart;
                     if ( ( pAttr->GetStart() <= nCursorPos ) && ( pAttr->GetEnd() >= nCursorPos ) )
                     {
                         // To be used the attribute has to start BEFORE the position, or it must be a
@@ -530,17 +505,17 @@ SfxItemSet ImpEditEngine::GetAttribs( USHORT nPara, USHORT nStart, USHORT nEnd,
 }
 
 
-void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, BYTE nSpecial )
+void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, sal_uInt8 nSpecial )
 {
     aSel.Adjust( aEditDoc );
 
-    // Wenn keine Selektion => die Attribute aufs Wort anwenden.
-    // ( Der RTF-Perser sollte die Methode eigentlich nie ohne Range rufen )
+    // When no selection => use the Attribute on the word.
+    // ( the RTF-parser should actually never call the Method whithout a Range )
     if ( ( nSpecial == ATTRSPECIAL_WHOLEWORD ) && !aSel.HasRange() )
-        aSel = SelectWord( aSel, ::com::sun::star::i18n::WordType::ANYWORD_IGNOREWHITESPACES, FALSE );
+        aSel = SelectWord( aSel, ::com::sun::star::i18n::WordType::ANYWORD_IGNOREWHITESPACES, sal_False );
 
-    USHORT nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
-    USHORT nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
+    sal_uInt16 nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
+    sal_uInt16 nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
 
     if ( IsUndoEnabled() && !IsInUndo() && aStatus.DoUndoAttribs() )
     {
@@ -549,7 +524,7 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, BYTE
         InsertUndo( pUndo );
     }
 
-    BOOL bCheckLanguage = FALSE;
+    sal_Bool bCheckLanguage = sal_False;
     if ( GetStatus().DoOnlineSpelling() )
     {
         bCheckLanguage = ( rSet.GetItemState( EE_CHAR_LANGUAGE ) == SFX_ITEM_ON ) ||
@@ -557,37 +532,37 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, BYTE
                          ( rSet.GetItemState( EE_CHAR_LANGUAGE_CTL ) == SFX_ITEM_ON );
     }
 
-    // ueber die Absaetze iterieren...
-    for ( USHORT nNode = nStartNode; nNode <= nEndNode; nNode++	)
+    // iterate over the paragraphs ...
+    for ( sal_uInt16 nNode = nStartNode; nNode <= nEndNode; nNode++	)
     {
-        BOOL bParaAttribFound = FALSE;
-        BOOL bCharAttribFound = FALSE;
+        sal_Bool bParaAttribFound = sal_False;
+        sal_Bool bCharAttribFound = sal_False;
 
         ContentNode* pNode = aEditDoc.GetObject( nNode );
         ParaPortion* pPortion = GetParaPortions().GetObject( nNode );
 
-        DBG_ASSERT( aEditDoc.SaveGetObject( nNode ), "Node nicht gefunden: SetAttribs" );
-        DBG_ASSERT( GetParaPortions().GetObject( nNode ), "Portion nicht gefunden: SetAttribs" );
+        DBG_ASSERT( aEditDoc.SaveGetObject( nNode ), "Node not founden: SetAttribs" );
+        DBG_ASSERT( GetParaPortions().GetObject( nNode ), "Portion not found: SetAttribs" );
 
         xub_StrLen nStartPos = 0;
         xub_StrLen nEndPos = pNode->Len();
         if ( nNode == nStartNode )
             nStartPos = aSel.Min().GetIndex();
-        if ( nNode == nEndNode ) // kann auch == nStart sein!
+        if ( nNode == nEndNode ) // can also be == nStart!
             nEndPos = aSel.Max().GetIndex();
 
-        // ueber die Items iterieren...
+        // Iterate over the Items...
 #ifdef EDITDEBUG
 //		FILE* fp = fopen( "d:\\debug.log", "a" );
 //		if ( fp )
 //		{
-//			fprintf( fp, "\n\n=> Zeichen-Attribute: Absatz %i, %i-%i\n", nNode, nStartPos, nEndPos );
-//			DbgOutItemSet( fp, rSet, TRUE, FALSE );
+//			fprintf( fp, "\n\n=> Character-Attribute: Paragraph %i, %i-%i\n", nNode, nStartPos, nEndPos );
+//			DbgOutItemSet( fp, rSet, sal_True, sal_False );
 //			fclose( fp );
 //		}
 #endif
 
-        for ( USHORT nWhich = EE_ITEMS_START; nWhich <= EE_CHAR_END; nWhich++)
+        for ( sal_uInt16 nWhich = EE_ITEMS_START; nWhich <= EE_CHAR_END; nWhich++)
         {
             if ( rSet.GetItemState( nWhich ) == SFX_ITEM_ON )
             {
@@ -595,17 +570,17 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, BYTE
                 if ( nWhich <= EE_PARA_END )
                 {
                     pNode->GetContentAttribs().GetItems().Put( rItem );
-                    bParaAttribFound = TRUE;
+                    bParaAttribFound = sal_True;
                 }
                 else
                 {
                     aEditDoc.InsertAttrib( pNode, nStartPos, nEndPos, rItem );
-                    bCharAttribFound = TRUE;
+                    bCharAttribFound = sal_True;
                     if ( nSpecial == ATTRSPECIAL_EDGE )
                     {
                         CharAttribArray& rAttribs = pNode->GetCharAttribs().GetAttribs();
-                        USHORT nAttrs = rAttribs.Count();
-                        for ( USHORT n = 0; n < nAttrs; n++ )
+                        sal_uInt16 nAttrs = rAttribs.Count();
+                        for ( sal_uInt16 n = 0; n < nAttrs; n++ )
                         {
                             EditCharAttrib* pAttr = rAttribs.GetObject( n );
                             if ( pAttr->GetStart() > nEndPos )
@@ -613,7 +588,7 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, BYTE
 
                             if ( ( pAttr->GetEnd() == nEndPos ) && ( pAttr->Which() == nWhich ) )
                             {
-                                pAttr->SetEdge( TRUE );
+                                pAttr->SetEdge( sal_True );
                                 break;
                             }
                         }
@@ -628,7 +603,7 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, BYTE
         }
         else if ( bCharAttribFound )
         {
-            bFormatted = FALSE;
+            bFormatted = sal_False;
             if ( !pNode->Len() || ( nStartPos != nEndPos  ) )
             {
                 pPortion->MarkSelectionInvalid( nStartPos, nEndPos-nStartPos );
@@ -639,59 +614,59 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, BYTE
     }
 }
 
-void ImpEditEngine::RemoveCharAttribs( EditSelection aSel, BOOL bRemoveParaAttribs, USHORT nWhich )
+void ImpEditEngine::RemoveCharAttribs( EditSelection aSel, sal_Bool bRemoveParaAttribs, sal_uInt16 nWhich )
 {
     aSel.Adjust( aEditDoc );
 
-    USHORT nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
-    USHORT nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
+    sal_uInt16 nStartNode = aEditDoc.GetPos( aSel.Min().GetNode() );
+    sal_uInt16 nEndNode = aEditDoc.GetPos( aSel.Max().GetNode() );
 
     const SfxItemSet* _pEmptyItemSet = bRemoveParaAttribs ? &GetEmptyItemSet() : 0;
 
     if ( IsUndoEnabled() && !IsInUndo() && aStatus.DoUndoAttribs() )
     {
-        // Eventuel spezielles Undo, oder ItemSet*
+        // Possibly a special Undo, or itemset*
         EditUndoSetAttribs* pUndo = CreateAttribUndo( aSel, GetEmptyItemSet() );
-        pUndo->SetRemoveAttribs( TRUE );
+        pUndo->SetRemoveAttribs( sal_True );
         pUndo->SetRemoveParaAttribs( bRemoveParaAttribs );
         pUndo->SetRemoveWhich( nWhich );
         InsertUndo( pUndo );
     }
 
-    // ueber die Absaetze iterieren...
-    for ( USHORT nNode = nStartNode; nNode <= nEndNode; nNode++	)
+    // iterate over the paragraphs ...
+    for ( sal_uInt16 nNode = nStartNode; nNode <= nEndNode; nNode++	)
     {
         ContentNode* pNode = aEditDoc.GetObject( nNode );
         ParaPortion* pPortion = GetParaPortions().GetObject( nNode );
 
-        DBG_ASSERT( aEditDoc.SaveGetObject( nNode ), "Node nicht gefunden: SetAttribs" );
-        DBG_ASSERT( GetParaPortions().SaveGetObject( nNode ), "Portion nicht gefunden: SetAttribs" );
+        DBG_ASSERT( aEditDoc.SaveGetObject( nNode ), "Node not found: SetAttribs" );
+        DBG_ASSERT( GetParaPortions().SaveGetObject( nNode ), "Portion not found: SetAttribs" );
 
         xub_StrLen nStartPos = 0;
         xub_StrLen nEndPos = pNode->Len();
         if ( nNode == nStartNode )
             nStartPos = aSel.Min().GetIndex();
-        if ( nNode == nEndNode ) // kann auch == nStart sein!
+        if ( nNode == nEndNode ) // can also be == nStart!
             nEndPos = aSel.Max().GetIndex();
 
-        // Optimieren: Wenn ganzer Absatz, dann RemoveCharAttribs( nPara )?!
-        BOOL bChanged = aEditDoc.RemoveAttribs( pNode, nStartPos, nEndPos, nWhich );
+        // Optimize: If whole paragraph, then RemoveCharAttribs (nPara)?
+        sal_Bool bChanged = aEditDoc.RemoveAttribs( pNode, nStartPos, nEndPos, nWhich );
         if ( bRemoveParaAttribs )
         {
-            SetParaAttribs( nNode, *_pEmptyItemSet );	// Invalidiert
+            SetParaAttribs( nNode, *_pEmptyItemSet );   // Invalidated
         }
         else
         {
-            // Bei 'Format-Standard' sollen auch die Zeichenattribute verschwinden,
-            // die von der DrawingEngine als Absatzattribute eingestellt wurden.
-            // Diese koennen sowieso nicht vom Anwender eingestellt worden sein.
+            // For 'Format-Standard' also the character attributes should 
+            // disappear, which were set as paragraph attributes by the 
+            // DrawingEngine. These could not have been set by the user anyway.
 
             // #106871# Not when nWhich
             // Would have been better to offer a separate method for format/standard...
             if ( !nWhich )
             {
                 SfxItemSet aAttribs( GetParaAttribs( nNode ) );
-                for ( USHORT nW = EE_CHAR_START; nW <= EE_CHAR_END; nW++ )
+                for ( sal_uInt16 nW = EE_CHAR_START; nW <= EE_CHAR_END; nW++ )
                     aAttribs.ClearItem( nW );
                 SetParaAttribs( nNode, aAttribs );
             }
@@ -699,7 +674,7 @@ void ImpEditEngine::RemoveCharAttribs( EditSelection aSel, BOOL bRemoveParaAttri
 
         if ( bChanged && !bRemoveParaAttribs )
         {
-            bFormatted = FALSE;
+            bFormatted = sal_False;
             pPortion->MarkSelectionInvalid( nStartPos, nEndPos-nStartPos );
         }
     }
@@ -707,18 +682,18 @@ void ImpEditEngine::RemoveCharAttribs( EditSelection aSel, BOOL bRemoveParaAttri
 
 typedef EditCharAttrib* EditCharAttribPtr;
 
-void ImpEditEngine::RemoveCharAttribs( USHORT nPara, USHORT nWhich, BOOL bRemoveFeatures )
+void ImpEditEngine::RemoveCharAttribs( sal_uInt16 nPara, sal_uInt16 nWhich, sal_Bool bRemoveFeatures )
 {
     ContentNode* pNode = aEditDoc.SaveGetObject( nPara );
     ParaPortion* pPortion = GetParaPortions().SaveGetObject( nPara );
 
-    DBG_ASSERT( pNode, "Node nicht gefunden: RemoveCharAttribs" );
-    DBG_ASSERT( pPortion, "Portion nicht gefunden: RemoveCharAttribs" );
+    DBG_ASSERT( pNode, "Node not found: RemoveCharAttribs" );
+    DBG_ASSERT( pPortion, "Portion not found: RemoveCharAttribs" );
 
     if ( !pNode )
         return;
 
-    USHORT nAttr = 0;
+    sal_uInt16 nAttr = 0;
     EditCharAttribPtr pAttr = GetAttrib( pNode->GetCharAttribs().GetAttribs(), nAttr );
     while ( pAttr )
     {
@@ -736,7 +711,7 @@ void ImpEditEngine::RemoveCharAttribs( USHORT nPara, USHORT nWhich, BOOL bRemove
     pPortion->MarkSelectionInvalid( 0, pNode->Len() );
 }
 
-void ImpEditEngine::SetParaAttribs( USHORT nPara, const SfxItemSet& rSet )
+void ImpEditEngine::SetParaAttribs( sal_uInt16 nPara, const SfxItemSet& rSet )
 {
     ContentNode* pNode = aEditDoc.SaveGetObject( nPara );
 
@@ -747,8 +722,8 @@ void ImpEditEngine::SetParaAttribs( USHORT nPara, const SfxItemSet& rSet )
 //		FILE* fp = fopen( "d:\\debug.log", "a" );
 //		if ( fp )
 //		{
-//			fprintf( fp, "\n\n=> Absatz-Attribute: Absatz %i\n", nPara );
-//			DbgOutItemSet( fp, rSet, TRUE, FALSE );
+//			fprintf( fp, "\n\n=> Paragraph-Attribute: Paragraph %i\n", nPara );
+//			DbgOutItemSet( fp, rSet, sal_True, sal_False );
 //			fclose( fp );
 //		}
 #endif
@@ -776,36 +751,36 @@ void ImpEditEngine::SetParaAttribs( USHORT nPara, const SfxItemSet& rSet )
     }
 }
 
-const SfxItemSet& ImpEditEngine::GetParaAttribs( USHORT nPara ) const
+const SfxItemSet& ImpEditEngine::GetParaAttribs( sal_uInt16 nPara ) const
 {
     ContentNode* pNode = aEditDoc.GetObject( nPara );
-    DBG_ASSERT( pNode, "Node nicht gefunden: GetParaAttribs" );
+    DBG_ASSERT( pNode, "Node not found: GetParaAttribs" );
     return pNode->GetContentAttribs().GetItems();
 }
 
-BOOL ImpEditEngine::HasParaAttrib( USHORT nPara, USHORT nWhich ) const
+sal_Bool ImpEditEngine::HasParaAttrib( sal_uInt16 nPara, sal_uInt16 nWhich ) const
 {
     ContentNode* pNode = aEditDoc.GetObject( nPara );
-    DBG_ASSERT( pNode, "Node nicht gefunden: HasParaAttrib" );
+    DBG_ASSERT( pNode, "Node not found: HasParaAttrib" );
 
     return pNode->GetContentAttribs().HasItem( nWhich );
 }
 
-const SfxPoolItem& ImpEditEngine::GetParaAttrib( USHORT nPara, USHORT nWhich ) const
+const SfxPoolItem& ImpEditEngine::GetParaAttrib( sal_uInt16 nPara, sal_uInt16 nWhich ) const
 {
     ContentNode* pNode = aEditDoc.GetObject( nPara );
-    DBG_ASSERT( pNode, "Node nicht gefunden: GetParaAttrib" );
+    DBG_ASSERT( pNode, "Node not found: GetParaAttrib" );
 
     return pNode->GetContentAttribs().GetItem( nWhich );
 }
 
-void ImpEditEngine::GetCharAttribs( USHORT nPara, EECharAttribArray& rLst ) const
+void ImpEditEngine::GetCharAttribs( sal_uInt16 nPara, EECharAttribArray& rLst ) const
 {
     rLst.Remove( 0, rLst.Count() );
     ContentNode* pNode = aEditDoc.GetObject( nPara );
     if ( pNode )
     {
-        for ( USHORT nAttr = 0; nAttr < pNode->GetCharAttribs().Count(); nAttr++ )
+        for ( sal_uInt16 nAttr = 0; nAttr < pNode->GetCharAttribs().Count(); nAttr++ )
         {
             EditCharAttribPtr pAttr = pNode->GetCharAttribs().GetAttribs()[ nAttr ];
             EECharAttrib aEEAttr;
@@ -822,13 +797,13 @@ void ImpEditEngine::ParaAttribsToCharAttribs( ContentNode* pNode )
 {
     pNode->GetCharAttribs().DeleteEmptyAttribs( GetEditDoc().GetItemPool() );
     xub_StrLen nEndPos = pNode->Len();
-    for ( USHORT nWhich = EE_CHAR_START; nWhich <= EE_CHAR_END; nWhich++ )
+    for ( sal_uInt16 nWhich = EE_CHAR_START; nWhich <= EE_CHAR_END; nWhich++ )
     {
         if ( pNode->GetContentAttribs().HasItem( nWhich ) )
         {
             const SfxPoolItem& rItem = pNode->GetContentAttribs().GetItem( nWhich );
-            // Die Luecken auffuellen:
-            USHORT nLastEnd = 0;
+            // Fill the gap:
+            sal_uInt16 nLastEnd = 0;
             EditCharAttrib* pAttr = pNode->GetCharAttribs().FindNextAttrib( nWhich, nLastEnd );
             while ( pAttr )
             {
@@ -839,13 +814,13 @@ void ImpEditEngine::ParaAttribsToCharAttribs( ContentNode* pNode )
                 pAttr = nLastEnd ? pNode->GetCharAttribs().FindNextAttrib( nWhich, nLastEnd ) : NULL;
             }
 
-            // Und den Rest:
+            // And the Rest:
             if ( nLastEnd < nEndPos )
                 aEditDoc.InsertAttrib( pNode, nLastEnd, nEndPos, rItem );
         }
     }
-    bFormatted = FALSE;
-    // Portion braucht hier nicht invalidiert werden, geschieht woanders.
+    bFormatted = sal_False;
+    // Portion does not need to be invalidated here, happens elsewhere.
 }
 
 IdleFormattter::IdleFormattter()
@@ -886,9 +861,9 @@ ImplIMEInfos::ImplIMEInfos( const EditPaM& rPos, const String& rOldTextAfterStar
 {
     aPos = rPos;
     nLen = 0;
-    bCursor = TRUE;
+    bCursor = sal_True;
     pAttribs = NULL;
-    bWasCursorOverwrite = FALSE;
+    bWasCursorOverwrite = sal_False;
 }
 
 ImplIMEInfos::~ImplIMEInfos()
@@ -896,12 +871,12 @@ ImplIMEInfos::~ImplIMEInfos()
     delete[] pAttribs;
 }
 
-void ImplIMEInfos::CopyAttribs( const USHORT* pA, USHORT nL )
+void ImplIMEInfos::CopyAttribs( const sal_uInt16* pA, sal_uInt16 nL )
 {
     nLen = nL;
     delete[] pAttribs;
-    pAttribs = new USHORT[ nL ];
-    memcpy( pAttribs, pA, nL*sizeof(USHORT) );
+    pAttribs = new sal_uInt16[ nL ];
+    memcpy( pAttribs, pA, nL*sizeof(sal_uInt16) );
 }
 
 void ImplIMEInfos::DestroyAttribs()
