@@ -252,7 +252,7 @@ sal_Bool CMtaFolderPicker::browseForFolder( )
 
         if ( WaitForSingleObject( m_hEvtThrdReady, MAX_WAITTIME ) != WAIT_OBJECT_0 )
         {
-            OSL_ENSURE( sal_False, "sta thread not ready" );
+            OSL_FAIL( "sta thread not ready" );
             return sal_False;
         }
         
@@ -280,7 +280,7 @@ sal_Bool CMtaFolderPicker::browseForFolder( )
         while ( bContinue )
         {
             DWORD dwResult = MsgWaitForMultipleObjects(
-                1, &aReqCtx.hEvent, FALSE, INFINITE, QS_ALLEVENTS );
+                1, &aReqCtx.hEvent, sal_False, INFINITE, QS_ALLEVENTS );
             
             switch ( dwResult )
             {
@@ -547,7 +547,7 @@ void SAL_CALL CMtaFolderPicker::onInitialized( )
         SendMessageA( 
             m_hwnd, 
             BFFM_SETSELECTION, 
-            (WPARAM)FALSE, 
+            (WPARAM)sal_False, 
             (LPARAM) lpiidDisplayDir );
 
         releaseItemIdList( lpiidDisplayDir );    
@@ -721,7 +721,7 @@ unsigned int CMtaFolderPicker::run( )
     // we stop here and return 
     if ( FAILED( hr ) )
     {
-        OSL_ENSURE( sal_False, "CoInitialize failed" );
+        OSL_FAIL( "CoInitialize failed" );
         return sal::static_int_cast< unsigned int >(-1);
     }
     
@@ -740,7 +740,7 @@ unsigned int CMtaFolderPicker::run( )
     }
     else
     {        
-        OSL_ENSURE( sal_False, "failed to create sta thread" );        
+        OSL_FAIL( "failed to create sta thread" );        
         nRet = sal::static_int_cast< unsigned int >(-1);
     }
 
