@@ -150,8 +150,8 @@ namespace basprov
                 Reference< lang::XMultiComponentFactory > xSMgr( m_xContext->getServiceManager() );
                 if ( xSMgr.is() )
                 {
-                    xUriFac.set( xSMgr->createInstanceWithContext( ::rtl::OUString::createFromAscii(
-                        "com.sun.star.uri.UriReferenceFactory" ), m_xContext ), UNO_QUERY );
+                    xUriFac.set( xSMgr->createInstanceWithContext( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                        "com.sun.star.uri.UriReferenceFactory" )), m_xContext ), UNO_QUERY );
                 }
 
                 if ( xUriFac.is() )
@@ -175,7 +175,7 @@ namespace basprov
                                 aDecodedURL = ::rtl::Uri::decode( aDecodedURL, rtl_UriDecodeWithCharset, RTL_TEXTENCODING_UTF8 );
                                 Reference<util::XMacroExpander> xMacroExpander(
                                     m_xContext->getValueByName(
-                                    ::rtl::OUString::createFromAscii( "/singletons/com.sun.star.util.theMacroExpander" ) ),
+                                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/singletons/com.sun.star.util.theMacroExpander")) ),
                                     UNO_QUERY );
                                 if ( xMacroExpander.is() )
                                     aFileURL = xMacroExpander->expandMacros( aDecodedURL );
@@ -338,8 +338,8 @@ namespace basprov
         Reference< provider::XScript > xScript;
         Reference< lang::XMultiComponentFactory > xMcFac ( m_xContext->getServiceManager() );
         Reference< uri::XUriReferenceFactory > xFac (
-            xMcFac->createInstanceWithContext( rtl::OUString::createFromAscii(
-            "com.sun.star.uri.UriReferenceFactory"), m_xContext ) , UNO_QUERY );
+            xMcFac->createInstanceWithContext( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "com.sun.star.uri.UriReferenceFactory")), m_xContext ) , UNO_QUERY );
 
         if ( !xFac.is() )
         {
@@ -356,7 +356,7 @@ namespace basprov
 
         if ( !uriRef.is() || !sfUri.is() )
         {
-            ::rtl::OUString errorMsg = ::rtl::OUString::createFromAscii( "BasicProviderImpl::getScript: failed to parse URI: " );
+            ::rtl::OUString errorMsg(RTL_CONSTASCII_USTRINGPARAM("BasicProviderImpl::getScript: failed to parse URI: "));
             errorMsg = errorMsg.concat( scriptURI );
             throw provider::ScriptFrameworkErrorException(
                 errorMsg, Reference< XInterface >(),
@@ -367,18 +367,18 @@ namespace basprov
 
         ::rtl::OUString aDescription = sfUri->getName();
         ::rtl::OUString aLocation = sfUri->getParameter(
-            ::rtl::OUString::createFromAscii( "location" ) );
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("location")) );
 
         sal_Int32 nIndex = 0;
         // In some strange circumstances the Library name can have an
         // apparantly illegal '.' in it ( in imported VBA )
 
         BasicManager* pBasicMgr =  NULL;
-        if ( aLocation.equals( ::rtl::OUString::createFromAscii("document") ) )
+        if ( aLocation.equals( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("document")) ) )
         {
             pBasicMgr = m_pDocBasicManager;
         }
-        else if ( aLocation.equals( ::rtl::OUString::createFromAscii("application") ) )
+        else if ( aLocation.equals( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("application")) ) )
         {
             pBasicMgr = m_pAppBasicManager;
         }
@@ -412,7 +412,7 @@ namespace basprov
                 StarBASIC* pBasic = pBasicMgr->GetLib( aLibrary );
                 if ( !pBasic )
                 {
-                    USHORT nId = pBasicMgr->GetLibId( aLibrary );
+                    sal_uInt16 nId = pBasicMgr->GetLibId( aLibrary );
                     if ( nId != LIB_NOTFOUND )
                     {
                         pBasicMgr->LoadLib( nId );
@@ -469,7 +469,7 @@ namespace basprov
 
         SolarMutexGuard aGuard;
 
-        return ::rtl::OUString::createFromAscii( "Basic" );
+        return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Basic"));
     }
 
     // -----------------------------------------------------------------------------
@@ -605,13 +605,6 @@ extern "C"
         *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
     }
 
-    SAL_DLLPUBLIC_EXPORT sal_Bool SAL_CALL component_writeInfo(
-        lang::XMultiServiceFactory * pServiceManager, registry::XRegistryKey * pRegistryKey )
-    {
-        return ::cppu::component_writeInfoHelper(
-            pServiceManager, pRegistryKey, ::basprov::s_component_entries );
-    }
-
     SAL_DLLPUBLIC_EXPORT void * SAL_CALL component_getFactory(
         const sal_Char * pImplName, lang::XMultiServiceFactory * pServiceManager,
         registry::XRegistryKey * pRegistryKey )
