@@ -50,10 +50,12 @@
 #include <sfx2/frame.hxx>
 #include <sfx2/sfxdlg.hxx>
 #include <vcl/abstdlg.hxx>
+#include <tools/diagnose_ex.h>
 
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/exc_hlp.hxx>
 #include <util/util.hxx>
+#include <framework/documentundoguard.hxx>
 
 #include "com/sun/star/uno/XComponentContext.hpp"
 #include "com/sun/star/uri/XUriReference.hpp"
@@ -70,7 +72,6 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::script;
 using namespace ::com::sun::star::script::provider;
 using namespace ::com::sun::star::document;
-using namespace ::scripting_util;
 
 namespace scripting_protocolhandler
 {
@@ -98,8 +99,7 @@ void SAL_CALL ScriptProtocolHandler::initialize(
         throw RuntimeException( temp, Reference< XInterface >() );
     }
 
-    validateXRef( m_xFactory,
-        "ScriptProtocolHandler::initialize: No Service Manager available" );
+    ENSURE_OR_THROW( m_xFactory.is(), "ScriptProtocolHandler::initialize: No Service Manager available" );
     m_bInitialised = true;
 }
 
@@ -114,8 +114,8 @@ Reference< XDispatch > SAL_CALL ScriptProtocolHandler::queryDispatch(
     // get scheme of url
 
     Reference< uri::XUriReferenceFactory > xFac ( 
-         m_xFactory->createInstance( rtl::OUString::createFromAscii( 
-            "com.sun.star.uri.UriReferenceFactory") ) , UNO_QUERY );
+         m_xFactory->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "com.sun.star.uri.UriReferenceFactory")) ) , UNO_QUERY );
     if ( xFac.is() )
     {
         Reference<  uri::XUriReference > uriRef(
@@ -156,14 +156,14 @@ void SAL_CALL ScriptProtocolHandler::dispatchWithNotification(
 
     sal_Bool bSuccess = sal_False;
     Any invokeResult;
-    bool bCaughtException = FALSE;
+    bool bCaughtException = sal_False;
     Any aException;
 
     if ( m_bInitialised )
     {
         try
         {
-            bool bIsDocumentScript = ( aURL.Complete.indexOf( ::rtl::OUString::createFromAscii( "document" ) ) !=-1 );
+            bool bIsDocumentScript = ( aURL.Complete.indexOfAsciiL( RTL_CONSTASCII_STRINGPARAM( "document" ) ) !=-1 );
                 // TODO: isn't this somewhat strange? This should be a test for a location=document parameter, shouldn't it?
 
             if ( bIsDocumentScript )
@@ -183,7 +183,7 @@ void SAL_CALL ScriptProtocolHandler::dispatchWithNotification(
 
             Reference< provider::XScript > xFunc =
                 m_xScriptProvider->getScript( aURL.Complete );
-            validateXRef( xFunc,
+            ENSURE_OR_THROW( xFunc.is(),
                 "ScriptProtocolHandler::dispatchWithNotification: validate xFunc - unable to obtain XScript interface" );
 
            
@@ -208,6 +208,11 @@ void SAL_CALL ScriptProtocolHandler::dispatchWithNotification(
                }
             }
 
+            // attempt to protect the document against the script tampering with its Undo Context
+            ::std::auto_ptr< ::framework::DocumentUndoGuard > pUndoGuard;
+            if ( bIsDocumentScript )
+                pUndoGuard.reset( new ::framework::DocumentUndoGuard( m_xScriptInvocation ) );
+
             bSuccess = sal_False;
             while ( !bSuccess )
             {
@@ -247,24 +252,14 @@ void SAL_CALL ScriptProtocolHandler::dispatchWithNotification(
 
             invokeResult <<= reason.concat( aException.getValueTypeName() ).concat( e.Message );
 
-            bCaughtException = TRUE;
+            bCaughtException = sal_True;
         }
-#ifdef _DEBUG
-        catch ( ... )
-        {
-            ::rtl::OUString reason = ::rtl::OUString::createFromAscii(
-                "ScriptProtocolHandler::dispatch: caught unknown exception" );
-
-            invokeResult <<= reason;
-        }
-#endif
-
     }
     else
     {
-        ::rtl::OUString reason = ::rtl::OUString::createFromAscii(
+        ::rtl::OUString reason(RTL_CONSTASCII_USTRINGPARAM(
         "ScriptProtocolHandler::dispatchWithNotification failed, ScriptProtocolHandler not initialised"
-        );
+        ));
         invokeResult <<= reason;
     }
 
@@ -359,13 +354,11 @@ ScriptProtocolHandler::getScriptInvocation()
     return m_xScriptInvocation.is();
 }
 
-void
-ScriptProtocolHandler::createScriptProvider() 
+void ScriptProtocolHandler::createScriptProvider() 
 {
     if ( m_xScriptProvider.is() )
-    {
         return;	
-    }
+
     try
     {
         // first, ask the component supporting the XScriptInvocationContext interface
@@ -398,6 +391,7 @@ ScriptProtocolHandler::createScriptProvider()
                 m_xScriptProvider = xSPS->getScriptProvider();
         }
 
+        // if nothing of this is successful, use the master script provider
         if ( !m_xScriptProvider.is() )
         {
             Reference< XPropertySet > xProps( m_xFactory, UNO_QUERY_THROW );
@@ -408,8 +402,8 @@ ScriptProtocolHandler::createScriptProvider()
             Reference< XComponentContext > xCtx(
                 xProps->getPropertyValue( dc ), UNO_QUERY_THROW );
 
-            ::rtl::OUString tmspf = ::rtl::OUString::createFromAscii(
-                "/singletons/com.sun.star.script.provider.theMasterScriptProviderFactory");
+            ::rtl::OUString tmspf(RTL_CONSTASCII_USTRINGPARAM(
+                "/singletons/com.sun.star.script.provider.theMasterScriptProviderFactory"));
 
             Reference< provider::XScriptProviderFactory > xFac(
                 xCtx->getValueByName( tmspf ), UNO_QUERY_THROW );
@@ -431,15 +425,6 @@ ScriptProtocolHandler::createScriptProvider()
         ::rtl::OUString temp = OUSTR( "ScriptProtocolHandler::createScriptProvider: " );
         throw RuntimeException( temp.concat( e.Message ), Reference< XInterface >() );
     }
-#ifdef _DEBUG
-    catch ( ... )
-    {
-        throw RuntimeException(
-        OUSTR( "ScriptProtocolHandler::createScriptProvider: UnknownException: " ),
-            Reference< XInterface > () );
-    }
-#endif
-        
 }
 
 ScriptProtocolHandler::ScriptProtocolHandler(
@@ -538,27 +523,6 @@ extern "C"
         *ppEnvironmentTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME ;
     }
 
-    sal_Bool SAL_CALL component_writeInfo( void * pServiceManager ,
-                                           void * pRegistryKey )
-    {
-        (void)pServiceManager;
-
-        Reference< css::registry::XRegistryKey > xKey( 
-            reinterpret_cast< css::registry::XRegistryKey* >( pRegistryKey ) ) ;
-
-        ::rtl::OUString aStr = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "/" ) );
-        aStr +=
-            ::scripting_protocolhandler::ScriptProtocolHandler::impl_getStaticImplementationName();
-
-        aStr += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "/UNO/SERVICES" ) );
-        Reference< css::registry::XRegistryKey > xNewKey = xKey->createKey( aStr );
-        xNewKey->createKey( 
-            ::rtl::OUString::createFromAscii( ::scripting_protocolhandler::MYSERVICENAME )
-            );
-
-        return sal_True;
-    }
-
     void* SAL_CALL component_getFactory( const sal_Char * pImplementationName ,
                                          void * pServiceManager ,
                                          void * pRegistryKey )
