@@ -170,7 +170,7 @@ public:
 
 
 //typedef ::std::map< ::rtl::OUString, Reference< browse::XBrowseNode > >
-typedef ::std::hash_map< ::rtl::OUString, Reference< browse::XBrowseNode >,
+typedef ::boost::unordered_map< ::rtl::OUString, Reference< browse::XBrowseNode >,
     ::rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > >
         BrowseNodeAggregatorHash;
 typedef ::std::vector< ::rtl::OUString > vString;
@@ -265,7 +265,7 @@ private:
         for ( sal_Int32 i = 0; i < langNodes.getLength(); i++ )
         {
             Reference< browse::XBrowseNode > xbn;
-            if ( langNodes[ i ]->getName().equals(::rtl::OUString::createFromAscii("uno_packages")) )
+            if ( langNodes[ i ]->getName().equals(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("uno_packages"))) )
             {
                 xbn.set( new LocationBrowseNode( langNodes[ i ] ) );
             }
@@ -325,8 +325,8 @@ Sequence< Reference< browse::XBrowseNode > > getAllBrowseNodes( const Reference<
             xCtx->getValueByName(
                 OUSTR("/singletons/com.sun.star.script.provider.theMasterScriptProviderFactory") ), UNO_QUERY_THROW );
 
-        locnBNs[ mspIndex++ ] = Reference< browse::XBrowseNode >( xFac->createScriptProvider( makeAny( ::rtl::OUString::createFromAscii("user") ) ), UNO_QUERY_THROW );
-        locnBNs[ mspIndex++ ] = Reference< browse::XBrowseNode >( xFac->createScriptProvider( makeAny( ::rtl::OUString::createFromAscii("share") ) ), UNO_QUERY_THROW );
+        locnBNs[ mspIndex++ ] = Reference< browse::XBrowseNode >( xFac->createScriptProvider( makeAny( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("user")) ) ), UNO_QUERY_THROW );
+        locnBNs[ mspIndex++ ] = Reference< browse::XBrowseNode >( xFac->createScriptProvider( makeAny( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("share")) ) ), UNO_QUERY_THROW );
     }
     // TODO proper exception handling, should throw
     catch( Exception& e )
@@ -418,7 +418,7 @@ public:
         }
         catch(  uno::Exception& )
         {
-            OSL_ENSURE( false, "DefaultBrowseNode::DefaultBrowseNode: Caught exception!" );
+            OSL_FAIL( "DefaultBrowseNode::DefaultBrowseNode: Caught exception!" );
         }
         OSL_ENSURE( m_xAggProxy.is(),
             "DefaultBrowseNode::DefaultBrowseNode: Wrapped BrowseNode cannot be aggregated!" );
@@ -570,7 +570,7 @@ public:
         {
             m_vNodes.push_back( new DefaultBrowseNode( xCtx, nodes[ i ] ) );
         }
-        m_Name = ::rtl::OUString::createFromAscii( "Root" );
+        m_Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Root"));
     }
 
     ~DefaultRootBrowseNode()
@@ -638,7 +638,7 @@ public:
     virtual ::rtl::OUString SAL_CALL getName()
         throw ( RuntimeException )
     {
-        return ::rtl::OUString::createFromAscii( "Root" );
+        return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Root"));
     }
 
     virtual Sequence< Reference< browse::XBrowseNode > > SAL_CALL
@@ -736,8 +736,8 @@ Sequence< ::rtl::OUString > SAL_CALL
 bnf_getSupportedServiceNames( )
     SAL_THROW( () )
 {
-    ::rtl::OUString str_name = ::rtl::OUString::createFromAscii(
-        "com.sun.star.script.browse.BrowseNodeFactory");
+    ::rtl::OUString str_name(RTL_CONSTASCII_USTRINGPARAM(
+        "com.sun.star.script.browse.BrowseNodeFactory"));
 
     return Sequence< ::rtl::OUString >( &str_name, 1 );
 }
@@ -746,8 +746,8 @@ bnf_getSupportedServiceNames( )
 bnf_getImplementationName( )
     SAL_THROW( () )
 {
-    return ::rtl::OUString::createFromAscii(
-        "com.sun.star.script.browse.BrowseNodeFactory" );
+    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+        "com.sun.star.script.browse.BrowseNodeFactory" ));
 }
 
 Reference< XInterface > SAL_CALL
