@@ -67,7 +67,7 @@
 #endif
 #include <vcl/timer.hxx>
 
-#include "sfxresid.hxx"
+#include "sfx2/sfxresid.hxx"
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::frame;
@@ -77,7 +77,11 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::ui::dialogs;
+#ifdef WNT
+using ::rtl::OUString;
+#else
 using namespace ::rtl;
+#endif
 using namespace ::sfx2;
 
 #ifdef ENABLE_QUICKSTART_APPLET
@@ -86,6 +90,10 @@ extern "C" { static void SAL_CALL thisModule() {} }
 # endif
 #endif
 
+#if defined(UNX) && defined(ENABLE_SYSTRAY_GTK)
+#define PLUGIN_NAME "libqstart_gtkli.so"
+#endif
+
 class SfxNotificationListener_Impl : public cppu::WeakImplHelper1< XDispatchResultListener >
 {
 public:
@@ -283,7 +291,7 @@ void ShutdownIcon::OpenURL( const ::rtl::OUString& aURL, const ::rtl::OUString&
             aDispatchURL.Complete = aURL;
 
             Reference < com::sun::star::util::XURLTransformer > xURLTransformer(
-                ::comphelper::getProcessServiceFactory()->createInstance( OUString::createFromAscii("com.sun.star.util.URLTransformer") ),
+                ::comphelper::getProcessServiceFactory()->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.util.URLTransformer")) ),
                 com::sun::star::uno::UNO_QUERY );
             if ( xURLTransformer.is() )
             {
@@ -333,7 +341,7 @@ void ShutdownIcon::FromTemplate()
 
         URL aTargetURL;
         aTargetURL.Complete = OUString( RTL_CONSTASCII_USTRINGPARAM( "slot:5500" ) );
-        Reference < XURLTransformer > xTrans( ::comphelper::getProcessServiceFactory()->createInstance( rtl::OUString::createFromAscii("com.sun.star.util.URLTransformer" )), UNO_QUERY );
+        Reference < XURLTransformer > xTrans( ::comphelper::getProcessServiceFactory()->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.util.URLTransformer"))), UNO_QUERY );
         xTrans->parseStrict( aTargetURL );
 
         Reference < ::com::sun::star::frame::XDispatchProvider > xProv( xFrame, UNO_QUERY );
@@ -343,14 +351,14 @@ void ShutdownIcon::FromTemplate()
             if ( aTargetURL.Protocol.compareToAscii("slot:") == COMPARE_EQUAL )
                 xDisp = xProv->queryDispatch( aTargetURL, ::rtl::OUString(), 0 );
             else
-                xDisp = xProv->queryDispatch( aTargetURL, ::rtl::OUString::createFromAscii("_blank"), 0 );
+                xDisp = xProv->queryDispatch( aTargetURL, ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("_blank")), 0 );
         }
         if ( xDisp.is() )
         {
             Sequence<PropertyValue> aArgs(1);
             PropertyValue* pArg = aArgs.getArray();
-            pArg[0].Name = rtl::OUString::createFromAscii("Referer");
-            pArg[0].Value <<= ::rtl::OUString::createFromAscii("private:user");
+            pArg[0].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Referer"));
+            pArg[0].Value <<= ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("private:user"));
             Reference< ::com::sun::star::frame::XNotifyingDispatch > xNotifyer( xDisp, UNO_QUERY );
             if ( xNotifyer.is() )
             {
@@ -416,7 +424,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
 {
     DBG_ASSERT( pThis->m_pFileDlg, "ShutdownIcon, DialogClosedHdl_Impl(): no file dialog" );
 
-    // use ctor for filling up filters automatically! #89169#
+    // use ctor for filling up filters automatically!
     if ( ERRCODE_NONE == pThis->m_pFileDlg->GetError() )
     {
         Reference< XFilePicker >    xPicker = pThis->m_pFileDlg->GetFilePicker();
@@ -437,21 +445,21 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
                 Sequence< PropertyValue >   aArgs(3);
 
                 Reference < com::sun::star::task::XInteractionHandler > xInteraction(
-                    ::comphelper::getProcessServiceFactory()->createInstance( OUString::createFromAscii("com.sun.star.task.InteractionHandler") ),
+                    ::comphelper::getProcessServiceFactory()->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.task.InteractionHandler")) ),
                     com::sun::star::uno::UNO_QUERY );
 
-                aArgs[0].Name = OUString::createFromAscii( "InteractionHandler" );
+                aArgs[0].Name = OUString(RTL_CONSTASCII_USTRINGPARAM("InteractionHandler"));
                 aArgs[0].Value <<= xInteraction;
 
                 sal_Int16 nMacroExecMode = ::com::sun::star::document::MacroExecMode::USE_CONFIG;
-                aArgs[1].Name = OUString::createFromAscii( "MacroExecutionMode" );
+                aArgs[1].Name = OUString(RTL_CONSTASCII_USTRINGPARAM("MacroExecutionMode"));
                 aArgs[1].Value <<= nMacroExecMode;
 
                 sal_Int16 nUpdateDoc = ::com::sun::star::document::UpdateDocMode::ACCORDING_TO_CONFIG;
-                aArgs[2].Name = OUString::createFromAscii( "UpdateDocMode" );
+                aArgs[2].Name = OUString(RTL_CONSTASCII_USTRINGPARAM("UpdateDocMode"));
                 aArgs[2].Value <<= nUpdateDoc;
 
-                // pb: #102643# use the filedlghelper to get the current filter name,
+                // use the filedlghelper to get the current filter name,
                 // because it removes the extensions before you get the filter name.
                 OUString aFilterName( pThis->m_pFileDlg->GetCurrentFilter() );
 
@@ -465,12 +473,12 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
 
                     xPickerControls->getValue( ExtendedFilePickerElementIds::CHECKBOX_READONLY, 0 ) >>= bReadOnly;
 
-                    // #95239#: Only set porperty if readonly is set to TRUE
+                    // Only set porperty if readonly is set to TRUE
 
                     if ( bReadOnly )
                     {
                         aArgs.realloc( ++nArgs );
-                        aArgs[nArgs-1].Name  = OUString::createFromAscii( "ReadOnly" );
+                        aArgs[nArgs-1].Name  = OUString(RTL_CONSTASCII_USTRINGPARAM("ReadOnly"));
                         aArgs[nArgs-1].Value <<= bReadOnly;
                     }
 
@@ -485,7 +493,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
                         sal_Int16   uVersion = (sal_Int16)iVersion;
 
                         aArgs.realloc( ++nArgs );
-                        aArgs[nArgs-1].Name  = OUString::createFromAscii( "Version" );
+                        aArgs[nArgs-1].Name  = OUString(RTL_CONSTASCII_USTRINGPARAM("Version"));
                         aArgs[nArgs-1].Value <<= uVersion;
                     }
 
@@ -510,7 +518,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
                         if ( aFilterName.getLength() )
                         {
                             aArgs.realloc( ++nArgs );
-                            aArgs[nArgs-1].Name  = OUString::createFromAscii( "FilterName" );
+                            aArgs[nArgs-1].Name  = OUString(RTL_CONSTASCII_USTRINGPARAM("FilterName"));
                             aArgs[nArgs-1].Value <<= aFilterName;
                         }
                     }
@@ -522,7 +530,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
                 {
                     OUString    aBaseDirURL = sFiles[0];
                     if ( aBaseDirURL.getLength() > 0 && aBaseDirURL[aBaseDirURL.getLength()-1] != '/' )
-                        aBaseDirURL += OUString::createFromAscii("/");
+                        aBaseDirURL += OUString(RTL_CONSTASCII_USTRINGPARAM("/"));
 
                     int iFiles;
                     for ( iFiles = 1; iFiles < nFiles; iFiles++ )
@@ -540,7 +548,7 @@ IMPL_STATIC_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, EMPTYAR
     }
 
 #ifdef WNT
-    // #103346 Destroy dialog to prevent problems with custom controls
+    // Destroy dialog to prevent problems with custom controls
     // This fix is dependent on the dialog settings. Destroying the dialog here will
     // crash the non-native dialog implementation! Therefore make this dependent on
     // the settings.
@@ -754,14 +762,14 @@ void SAL_CALL ShutdownIcon::initialize( const ::com::sun::star::uno::Sequence< :
 
 void ShutdownIcon::EnterModalMode()
 {
-    bModalMode = TRUE;
+    bModalMode = sal_True;
 }
 
 // -------------------------------
 
 void ShutdownIcon::LeaveModalMode()
 {
-    bModalMode = FALSE;
+    bModalMode = sal_False;
 }
 
 #ifdef WNT
@@ -859,7 +867,7 @@ bool ShutdownIcon::GetAutostart( )
     OUString aShortcutUrl;
     osl::File::getFileURLFromSystemPath( aShortcut, aShortcutUrl );
     osl::File f( aShortcutUrl );
-    osl::File::RC error = f.open( OpenFlag_Read );
+    osl::File::RC error = f.open( osl_File_OpenFlag_Read );
     if( error == osl::File::E_None )
     {
         f.close();
@@ -892,10 +900,10 @@ void ShutdownIcon::SetAutostart( bool bActivate )
                                                      osl_getThreadTextEncoding() );
         OString aShortcutUnx = OUStringToOString( aShortcut,
                                                   osl_getThreadTextEncoding() );
-        if ((0 != symlink(aDesktopFileUnx, aShortcutUnx)) && (errno == EEXIST))
+        if ((0 != symlink(aDesktopFileUnx.getStr(), aShortcutUnx.getStr())) && (errno == EEXIST))
         {
-            unlink(aShortcutUnx);
-            int ret = symlink(aDesktopFileUnx, aShortcutUnx);
+            unlink(aShortcutUnx.getStr());
+            int ret = symlink(aDesktopFileUnx.getStr(), aShortcutUnx.getStr());
             (void)ret; //deliberately ignore return value, it's non-critical if it fails
         }
 
