@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -63,7 +63,7 @@
 #include <vcl/oldprintadaptor.hxx>
 
 #include <sfx2/app.hxx>
-#include "sfxresid.hxx"
+#include "sfx2/sfxresid.hxx"
 #include "appdata.hxx"
 #include <sfx2/dinfdlg.hxx>
 #include "fltfnc.hxx"
@@ -72,11 +72,11 @@
 #include <sfx2/objsh.hxx>
 #include "objshimp.hxx"
 #include <sfx2/evntconf.hxx>
-#include "sfxhelp.hxx"
+#include "sfx2/sfxhelp.hxx"
 #include <sfx2/dispatch.hxx>
 #include <sfx2/printer.hxx>
+#include "sfx2/basmgr.hxx"
 #include <sfx2/viewfrm.hxx>
-#include "basmgr.hxx"
 #include <sfx2/doctempl.hxx>
 #include "doc.hrc"
 #include <sfx2/sfxbasemodel.hxx>
@@ -90,8 +90,6 @@ using namespace ::com::sun::star::uno;
 
 //====================================================================
 
-//====================================================================
-
 static
 bool operator> (const util::DateTime& i_rLeft, const util::DateTime& i_rRight)
 {
@@ -119,19 +117,17 @@ bool operator> (const util::DateTime& i_rLeft, const util::DateTime& i_rRight)
     return sal_False;
 }
 
-
 ::boost::shared_ptr<GDIMetaFile>
 SfxObjectShell::GetPreviewMetaFile( sal_Bool bFullContent ) const
 {
-    return CreatePreviewMetaFile_Impl( bFullContent, sal_False );
+    return CreatePreviewMetaFile_Impl( bFullContent );
 }
 
-
 ::boost::shared_ptr<GDIMetaFile>
-SfxObjectShell::CreatePreviewMetaFile_Impl( sal_Bool bFullContent, sal_Bool bHighContrast ) const
+SfxObjectShell::CreatePreviewMetaFile_Impl( sal_Bool bFullContent ) const
 {
-    // Nur wenn gerade nicht gedruckt wird, darf DoDraw aufgerufen
-    // werden, sonst wird u.U. der Printer abgeschossen !
+    // DoDraw can only be called when no printing is done, otherwise
+    // the printer may be turned off
     SfxViewFrame *pFrame = SfxViewFrame::GetFirst( this );
     if ( pFrame && pFrame->GetViewShell() &&
          pFrame->GetViewShell()->GetPrinter() &&
@@ -141,11 +137,7 @@ SfxObjectShell::CreatePreviewMetaFile_Impl( sal_Bool bFullContent, sal_Bool bHig
     ::boost::shared_ptr<GDIMetaFile> pFile(new GDIMetaFile);
 
     VirtualDevice aDevice;
-    aDevice.EnableOutput( FALSE );
-
-    // adjust the output device if HC-metafile is requested
-    if ( bHighContrast )
-        aDevice.SetDrawMode( aDevice.GetDrawMode() | DRAWMODE_SETTINGSLINE | DRAWMODE_SETTINGSFILL | DRAWMODE_SETTINGSTEXT | DRAWMODE_SETTINGSGRADIENT );
+    aDevice.EnableOutput( sal_False );
 
     MapMode aMode( ((SfxObjectShell*)this)->GetMapUnit() );
     aDevice.SetMapMode( aMode );
@@ -241,7 +233,7 @@ lcl_add(util::Duration & rDur, Time const& rTime)
     rDur.Seconds += rTime.GetSec();
 }
 
-// Bearbeitungszeit aktualisieren
+// Update the processing time
 void SfxObjectShell::UpdateTime_Impl(
     const uno::Reference<document::XDocumentProperties> & i_xDocProps)
 {
@@ -253,7 +245,7 @@ void SfxObjectShell::UpdateTime_Impl(
     // Initialize some local member! Its neccessary for wollow operations!
     DateTime	aNow					;	// Date and time at current moment
     Time		n24Time		(24,0,0,0)	;	// Time-value for 24 hours - see follow calculation
-    ULONG		nDays		= 0			;	// Count of days between now and last editing
+    sal_uIntPtr		nDays		= 0			;	// Count of days between now and last editing
     Time		nAddTime	(0)			;	// Value to add on aOldTime
 
     // Safe impossible cases!
@@ -329,11 +321,9 @@ void SfxObjectShell::SetOrganizerSearchMask(
 
 //--------------------------------------------------------------------
 
-USHORT SfxObjectShell::GetContentCount(
-    USHORT nIdx1,
-    USHORT /*nIdx2*/)
+sal_uInt16 SfxObjectShell::GetContentCount(sal_uInt16 nIdx)
 {
-    switch(nIdx1)
+    switch(nIdx)
     {
         case INDEX_IGNORE:
             return DEF_CONTENT_COUNT;
@@ -347,56 +337,34 @@ USHORT SfxObjectShell::GetContentCount(
         }
         case CONTENT_MACRO:
             break;
-/*
-        case CONTENT_CONFIG:
-            return ( GetConfigManager() ) ?
-                        GetConfigManager()->GetItemCount() : 0;
-            break;
- */
     }
     return 0;
 }
 
 
 //--------------------------------------------------------------------
-//TODO/CLEANUP: remove this method (it's virtual)
-void  SfxObjectShell::TriggerHelpPI(USHORT nIdx1, USHORT nIdx2, USHORT)
+//TODO/CLEANUP: remove this method
+void  SfxObjectShell::TriggerHelpPI(sal_uInt16 nIdx1, sal_uInt16 nIdx2)
 {
     if(nIdx1==CONTENT_STYLE && nIdx2 != INDEX_IGNORE) //StyleSheets
     {
         SfxStyleSheetBasePool *pStylePool = GetStyleSheetPool();
         SetOrganizerSearchMask(pStylePool);
-#ifdef WIR_KOENNEN_WIEDER_HILFE_FUER_STYLESHEETS
-        SfxStyleSheetBase *pStyle = (*pStylePool)[nIdx2];
-        if(pStyle)
-        {
-            String aHelpFile;
-            ULONG nHelpId=pStyle->GetHelpId(aHelpFile);
-            SfxHelpPI* pHelpPI = SFX_APP()->GetHelpPI();
-            if ( pHelpPI && nHelpId )
-                pHelpPI->LoadTopic( nHelpId );
-        }
-#endif
     }
 }
 
-BOOL   SfxObjectShell::CanHaveChilds(USHORT nIdx1,
-                                       USHORT nIdx2)
+sal_Bool SfxObjectShell::CanHaveChilds(sal_uInt16 nIdx1, sal_uInt16 nIdx2)
 {
-    switch(nIdx1) {
+    switch(nIdx1)
+    {
     case INDEX_IGNORE:
-        return TRUE;
+        return true;
     case CONTENT_STYLE:
-        return INDEX_IGNORE == nIdx2 || !GetStyleSheetPool()? FALSE: TRUE;
+        return INDEX_IGNORE == nIdx2 || !GetStyleSheetPool() ? false : true;
     case CONTENT_MACRO:
-//!!    return INDEX_IGNORE == nIdx2? FALSE: TRUE;
-        return FALSE;
-/*
-    case CONTENT_CONFIG:
-        return INDEX_IGNORE == nIdx2 ? FALSE : TRUE;
- */
+        return false;
     }
-    return FALSE;
+    return false;
 }
 
 //--------------------------------------------------------------------
@@ -404,70 +372,32 @@ BOOL   SfxObjectShell::CanHaveChilds(USHORT nIdx1,
 void SfxObjectShell::GetContent(String &rText,
                                 Bitmap &rClosedBitmap,
                                 Bitmap &rOpenedBitmap,
-                                BOOL &bCanDel,
-                                USHORT i,
-                                USHORT nIdx1,
-                                USHORT nIdx2 )
+                                sal_Bool &bCanDel,
+                                sal_uInt16 i,
+                                sal_uInt16 nIdx
+)
 {
-    DBG_ERRORFILE( "Non high contrast method called. Please update calling code!" );
-    SfxObjectShell::GetContent( rText, rClosedBitmap, rOpenedBitmap, BMP_COLOR_NORMAL, bCanDel, i, nIdx1, nIdx2 );
-}
+    bCanDel=true;
 
-//--------------------------------------------------------------------
-
-void   SfxObjectShell::GetContent(String &rText,
-                                  Bitmap &rClosedBitmap,
-                                  Bitmap &rOpenedBitmap,
-                                  BmpColorMode eColorMode,
-                                  BOOL &bCanDel,
-                                  USHORT i,
-                                  USHORT nIdx1,
-                                  USHORT /*nIdx2*/ )
-{
-    bCanDel=TRUE;
-
-    switch(nIdx1)
+    switch(nIdx)
     {
         case INDEX_IGNORE:
         {
-            USHORT nTextResId = 0;
-            USHORT nClosedBitmapResId = 0; // evtl. sp"ater mal unterschiedliche
-            USHORT nOpenedBitmapResId = 0; // "     "       "   "
+            sal_uInt16 nTextResId = 0;
+            sal_uInt16 nClosedBitmapResId = 0; // evtl. sp"ater mal unterschiedliche
+            sal_uInt16 nOpenedBitmapResId = 0; // "     "       "   "
             switch(i)
             {
                 case CONTENT_STYLE:
                     nTextResId = STR_STYLES;
-                    if ( eColorMode == BMP_COLOR_NORMAL )
-                    {
-                        nClosedBitmapResId= BMP_STYLES_CLOSED;
-                        nOpenedBitmapResId= BMP_STYLES_OPENED;
-                    }
-                    else
-                    {
-                        nClosedBitmapResId= BMP_STYLES_CLOSED_HC;
-                        nOpenedBitmapResId= BMP_STYLES_OPENED_HC;
-                    }
-                    break;
-                case CONTENT_MACRO:
-                    nTextResId = STR_MACROS;
-                    if ( eColorMode == BMP_COLOR_NORMAL )
-                    {
-                        nClosedBitmapResId= BMP_STYLES_CLOSED;
-                        nOpenedBitmapResId= BMP_STYLES_OPENED;
-                    }
-                    else
-                    {
-                        nClosedBitmapResId= BMP_STYLES_CLOSED_HC;
-                        nOpenedBitmapResId= BMP_STYLES_OPENED_HC;
-                    }
-                    break;
-/*
-                case CONTENT_CONFIG:
-                    nTextResId = STR_CONFIG;
                     nClosedBitmapResId= BMP_STYLES_CLOSED;
                     nOpenedBitmapResId= BMP_STYLES_OPENED;
                     break;
- */
+                case CONTENT_MACRO:
+                    nTextResId = STR_MACROS;
+                    nClosedBitmapResId= BMP_STYLES_CLOSED;
+                    nOpenedBitmapResId= BMP_STYLES_OPENED;
+                    break;
             }
 
             if ( nTextResId )
@@ -488,52 +418,32 @@ void   SfxObjectShell::GetContent(String &rText,
             bCanDel=((pStyle->GetMask() & SFXSTYLEBIT_USERDEF)
                      == SFXSTYLEBIT_USERDEF);
             rClosedBitmap = rOpenedBitmap =
-                GetStyleFamilyBitmap(pStyle->GetFamily(), eColorMode );
+                GetStyleFamilyBitmap(pStyle->GetFamily());
         }
             break;
         case CONTENT_MACRO:
             break;
-/*
-        case CONTENT_CONFIG:
-            if ( GetConfigManager() )
-            {
-                rText = GetConfigManager()->GetItem(i);
-                bCanDel = GetConfigManager()->CanDelete(i);
-            }
-            else
-                rText = String();
-            rClosedBitmap = Bitmap(SfxResId(BMP_STYLES_CLOSED));
-            rOpenedBitmap = Bitmap(SfxResId(BMP_STYLES_OPENED));
-            break;
-*/
     }
 }
 
 //--------------------------------------------------------------------
-Bitmap SfxObjectShell::GetStyleFamilyBitmap( SfxStyleFamily eFamily )
-{
-    DBG_ERRORFILE( "Non high contrast method called. Please update calling code!" );
-    return SfxObjectShell::GetStyleFamilyBitmap( eFamily, BMP_COLOR_NORMAL );
-}
 
-//--------------------------------------------------------------------
-
-Bitmap SfxObjectShell::GetStyleFamilyBitmap(SfxStyleFamily eFamily, BmpColorMode eColorMode )
+Bitmap SfxObjectShell::GetStyleFamilyBitmap(SfxStyleFamily eFamily)
 {
-    USHORT nResId = 0;
+    sal_uInt16 nResId = 0;
     switch(eFamily)
     {
         case SFX_STYLE_FAMILY_CHAR:
-            nResId = ( eColorMode == BMP_COLOR_NORMAL ) ? BMP_STYLES_FAMILY1 : BMP_STYLES_FAMILY1_HC;
+            nResId = BMP_STYLES_FAMILY1;
             break;
         case SFX_STYLE_FAMILY_PARA:
-            nResId = ( eColorMode == BMP_COLOR_NORMAL ) ? BMP_STYLES_FAMILY2 : BMP_STYLES_FAMILY2_HC;
+            nResId = BMP_STYLES_FAMILY2;
             break;
         case SFX_STYLE_FAMILY_FRAME:
-            nResId = ( eColorMode == BMP_COLOR_NORMAL ) ? BMP_STYLES_FAMILY3 : BMP_STYLES_FAMILY3_HC;
+            nResId = BMP_STYLES_FAMILY3;
             break;
         case SFX_STYLE_FAMILY_PAGE :
-            nResId = ( eColorMode == BMP_COLOR_NORMAL ) ? BMP_STYLES_FAMILY4 : BMP_STYLES_FAMILY4_HC;
+            nResId = BMP_STYLES_FAMILY4;
             break;
         case SFX_STYLE_FAMILY_PSEUDO:
         case SFX_STYLE_FAMILY_ALL:
@@ -549,16 +459,16 @@ Bitmap SfxObjectShell::GetStyleFamilyBitmap(SfxStyleFamily eFamily, BmpColorMode
 
 //--------------------------------------------------------------------
 
-BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
-                              USHORT nSourceIdx1,
-                              USHORT nSourceIdx2,
-                              USHORT /*nSourceIdx3*/,
-                              USHORT &nIdx1,
-                              USHORT &nIdx2,
-                              USHORT &/*nIdx3*/,
-                              USHORT &/*nDeleted*/)
+sal_Bool SfxObjectShell::Insert(SfxObjectShell &rSource,
+                              sal_uInt16 nSourceIdx1,
+                              sal_uInt16 nSourceIdx2,
+                              sal_uInt16 /*nSourceIdx3*/,
+                              sal_uInt16 &nIdx1,
+                              sal_uInt16 &nIdx2,
+                              sal_uInt16 &/*nIdx3*/,
+                              sal_uInt16 &/*nDeleted*/)
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if (INDEX_IGNORE == nIdx1 && CONTENT_STYLE == nSourceIdx1)
         nIdx1 = CONTENT_STYLE;
@@ -574,8 +484,8 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
         if ( pHisPool && pHisPool->Count() > nSourceIdx2 )
             pHisSheet = (*pHisPool)[nSourceIdx2];
 
-        // Einfuegen ist nur dann noetig, wenn ein StyleSheet
-        // zwischen unterschiedlichen(!) Pools bewegt wird
+        // Pasting is only needed if a style sheet is moved between
+        // different (!) Pools
 
         if ( pHisSheet && pMyPool != pHisPool )
         {
@@ -584,13 +494,12 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                 nIdx2 = pMyPool->Count();
             }
 
-            // wenn so eine Vorlage schon existiert: loeschen!
+            // if such a template already exists: delete!
             String aOldName(pHisSheet->GetName());
             SfxStyleFamily eOldFamily = pHisSheet->GetFamily();
 
             SfxStyleSheetBase* pExist = pMyPool->Find(aOldName, eOldFamily);
-            // USHORT nOldHelpId = pExist->GetHelpId(??? VB ueberlegt sich was);
-            BOOL bUsedOrUserDefined;
+            sal_Bool bUsedOrUserDefined;
             if( pExist )
             {
                 bUsedOrUserDefined =
@@ -598,13 +507,13 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                 if( ErrorHandler::HandleError(
                     *new MessageInfo( ERRCODE_SFXMSG_STYLEREPLACE, aOldName ) )
                     != ERRCODE_BUTTON_OK )
-                    return FALSE;
+                    return sal_False;
                 else
                 {
                     pMyPool->Replace( *pHisSheet, *pExist );
-                    SetModified( TRUE );
+                    SetModified( sal_True );
                     nIdx2 = nIdx1 = INDEX_IGNORE;
-                    return TRUE;
+                    return sal_True;
                 }
             }
 
@@ -612,10 +521,11 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                 aOldName, eOldFamily,
                 pHisSheet->GetMask(), nIdx2);
 
-            // ItemSet der neuen Vorlage fuellen
+            // Fill the Itemset of the new template
             rNewSheet.GetItemSet().Set(pHisSheet->GetItemSet());
 
-            // wer bekommt den Neuen als Parent? wer benutzt den Neuen als Follow?
+            // Who gets the new one as a Parent?
+            // Who is using the new one as Follow?
             SfxStyleSheetBase* pTestSheet = pMyPool->First();
             while (pTestSheet)
             {
@@ -624,7 +534,7 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                     pTestSheet->GetParent() == aOldName)
                 {
                     pTestSheet->SetParent(aOldName);
-                    // Verknuepfung neu aufbauen
+                    // Rebuild Link
                 }
 
                 if (pTestSheet->GetFamily() == eOldFamily &&
@@ -632,7 +542,7 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                     pTestSheet->GetFollow() == aOldName)
                 {
                     pTestSheet->SetFollow(aOldName);
-                    // Verknuepfung neu aufbauen
+                    // Rebuild Link
                 }
 
                 pTestSheet = pMyPool->Next();
@@ -641,7 +551,7 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                 rNewSheet.IsUsed() || rNewSheet.IsUserDefined();
 
 
-            // hat der Neue einen Parent? wenn ja, mit gleichem Namen bei uns suchen
+            // has a New Parent? if so, start search with the same name
             if (pHisSheet->HasParentSupport())
             {
                 const String& rParentName = pHisSheet->GetParent();
@@ -654,8 +564,8 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                 }
             }
 
-            // hat der Neue einen Follow? wenn ja, mit gleichem
-            // Namen bei uns suchen
+            // Has the new got a Follow? if so start search
+            // with the same name.
             if (pHisSheet->HasFollowSupport())
             {
                 const String& rFollowName = pHisSheet->GetFollow();
@@ -668,50 +578,28 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
                 }
             }
 
-            SetModified( TRUE );
+            SetModified( sal_True );
             if( !bUsedOrUserDefined ) nIdx2 = nIdx1 = INDEX_IGNORE;
 
-            bRet = TRUE;
+            bRet = sal_True;
         }
         else
-            bRet = FALSE;
+            bRet = sal_False;
     }
-/*
-    else if (nSourceIdx1 == CONTENT_CONFIG)
-    {
-        nIdx1 = CONTENT_CONFIG;
 
-        SfxConfigManager *pCfgMgr = SFX_CFGMANAGER();
-        if ( !GetConfigManager() )
-        {
-            SetConfigManager(new SfxConfigManager(0, pCfgMgr));
-            SetTemplateConfig(FALSE);
-            if (this == Current())
-                GetConfigManager()->Activate(pCfgMgr);
-        }
-
-        if (GetConfigManager()->CopyItem(
-            nSourceIdx2, nIdx2, rSource.GetConfigManager()))
-        {
-            SetModified(TRUE);
-            bRet = TRUE;
-            SFX_APP()->GetDispatcher_Impl()->Update_Impl(TRUE);
-        }
-    }
-*/
     return bRet;
 }
 
 //--------------------------------------------------------------------
 
-BOOL SfxObjectShell::Remove
+sal_Bool SfxObjectShell::Remove
 (
-    USHORT nIdx1,
-    USHORT nIdx2,
-    USHORT /*nIdx3*/
+    sal_uInt16 nIdx1,
+    sal_uInt16 nIdx2,
+    sal_uInt16 /*nIdx3*/
 )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if (CONTENT_STYLE == nIdx1)
     {
@@ -724,7 +612,7 @@ BOOL SfxObjectShell::Remove
         String aEmpty;
         SfxStyleFamily  eFamily = pMySheet->GetFamily();
         pMyPool->Remove(pMySheet);
-        bRet = TRUE;
+        bRet = sal_True;
 
         SfxStyleSheetBase* pTestSheet = pMyPool->First();
         while (pTestSheet)
@@ -733,20 +621,20 @@ BOOL SfxObjectShell::Remove
                 pTestSheet->HasParentSupport() &&
                 pTestSheet->GetParent() == aName)
             {
-                pTestSheet->SetParent(aEmpty); // Verknuepfung aufloesen
+                pTestSheet->SetParent(aEmpty); // Remove link
             }
 
             if (pTestSheet->GetFamily() == eFamily &&
                 pTestSheet->HasFollowSupport() &&
                 pTestSheet->GetFollow() == aName)
             {
-                pTestSheet->SetFollow(aEmpty); // Verknuepfung aufloesen
+                pTestSheet->SetFollow(aEmpty); // Remove link
             }
 
             pTestSheet = pMyPool->Next();
         }
 
-        SetModified( TRUE );
+        SetModified( sal_True );
     }
 
     return bRet;
@@ -754,18 +642,14 @@ BOOL SfxObjectShell::Remove
 
 //--------------------------------------------------------------------
 
-BOOL SfxObjectShell::Print
+sal_Bool SfxObjectShell::Print
 (
     Printer&        rPrt,
-    USHORT          nIdx1,
-    USHORT          /*nIdx2*/,
-    USHORT          /*nIdx3*/,
+    sal_uInt16          nIdx1,
+    sal_uInt16          /*nIdx2*/,
+    sal_uInt16          /*nIdx3*/,
     const String*   pObjectName
 )
-
-/*  [Beschreibung]
-*/
-
 {
     switch(nIdx1)
     {
@@ -775,12 +659,11 @@ BOOL SfxObjectShell::Print
             SetOrganizerSearchMask(pStylePool);
             SfxStyleSheetIterator* pIter = pStylePool->CreateIterator(
                 pStylePool->GetSearchFamily(), pStylePool->GetSearchMask() );
-            USHORT nStyles = pIter->Count();
             SfxStyleSheetBase *pStyle = pIter->First();
             if ( !pStyle )
-                return TRUE;
+                return sal_True;
 
-            // pepare adaptor for old style StartPage/EndPage printing
+            // prepare adaptor for old style StartPage/EndPage printing
             boost::shared_ptr< Printer > pPrinter( new Printer( rPrt.GetJobSetup() ) );
             vcl::OldStylePrintAdaptor* pAdaptor = new vcl::OldStylePrintAdaptor( pPrinter );
             boost::shared_ptr< vcl::PrinterController > pController( pAdaptor );
@@ -792,8 +675,8 @@ BOOL SfxObjectShell::Print
             aFont.SetWeight(WEIGHT_BOLD);
             pPrinter->SetFont(aFont);
             const Size aPageSize(pPrinter->GetOutputSize());
-            const USHORT nXIndent = 200;
-            USHORT nYIndent = 200;
+            const sal_uInt16 nXIndent = 200;
+            sal_uInt16 nYIndent = 200;
             Point aOutPos(nXIndent, nYIndent);
             String aHeader(SfxResId(STR_PRINT_STYLES_HEADER));
             if ( pObjectName )
@@ -805,7 +688,6 @@ BOOL SfxObjectShell::Print
             aOutPos.Y() += nTextHeight;
             aOutPos.Y() += nTextHeight/2;
             aFont.SetSize(Size(0, 35)); // 10pt
-            nStyles = 1;
             while(pStyle)
             {
                 // print template name
@@ -829,13 +711,13 @@ BOOL SfxObjectShell::Print
                 pPrinter->SetFont(aFont);
                 aStr = pStyle->GetDescription();
                 const char cDelim = ' ';
-                USHORT nStart = 0, nIdx = 0;
+                sal_uInt16 nStart = 0, nIdx = 0;
 
                 nTextHeight = pPrinter->GetTextHeight();
                 // break text into lines
                 while(nIdx < aStr.Len())
                 {
-                    USHORT	nOld = nIdx;
+                    sal_uInt16	nOld = nIdx;
                     long nTextWidth;
                     nIdx = aStr.Search(cDelim, nStart);
                     nTextWidth = pPrinter->GetTextWidth(aStr, nStart, nIdx-nStart);
@@ -856,7 +738,7 @@ BOOL SfxObjectShell::Print
                     }
                     else
                     {
-                        USHORT nChar = 1;
+                        sal_uInt16 nChar = 1;
                         while(
                             nStart + nChar < aStr.Len() &&
                             aOutPos.X() + pPrinter->GetTextWidth(
@@ -887,27 +769,26 @@ BOOL SfxObjectShell::Print
             break;
         }
       default:
-          return FALSE;
+          return sal_False;
     }
-    return TRUE;
+    return sal_True;
 }
 
 //--------------------------------------------------------------------
 
 void SfxObjectShell::LoadStyles
 (
-    SfxObjectShell &rSource         /*  die Dokument-Vorlage, aus der
-                                            die Styles geladen werden sollen */
+    SfxObjectShell &rSource         /*  the document template from which
+                                        the styles are to be loaded */
 )
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Diese Methode wird vom SFx gerufen, wenn aus einer Dokument-Vorlage
-    Styles nachgeladen werden sollen. Bestehende Styles soll dabei
-    "uberschrieben werden. Das Dokument mu"s daher neu formatiert werden.
-    Daher werden die Applikationen in der Regel diese Methode "uberladen
-    und in ihrer Implementierung die Implementierung der Basisklasse
-    rufen.
+    This method is called by the SFx if template styles are to be loaded.
+    Existing styles are in this case overwritten. The document has then to be
+    newly formatted. Therefore, the application of this method is usually
+    overloaded and its implementation is calling the implementation in
+    the base class.
 */
 
 {
@@ -915,7 +796,6 @@ void SfxObjectShell::LoadStyles
     {
         SfxStyleSheetBase *pSource;
         SfxStyleSheetBase *pDest;
-//      Styles_Impl () : pSource(0), pDest(0) {}
     };
 
     SfxStyleSheetBasePool *pSourcePool = rSource.GetStyleSheetPool();
@@ -924,7 +804,7 @@ void SfxObjectShell::LoadStyles
     DBG_ASSERT(pMyPool, "Dest-DocumentShell ohne StyleSheetPool");
     pSourcePool->SetSearchMask(SFX_STYLE_FAMILY_ALL, 0xffff);
     Styles_Impl *pFound = new Styles_Impl[pSourcePool->Count()];
-    USHORT nFound = 0;
+    sal_uInt16 nFound = 0;
 
     SfxStyleSheetBase *pSource = pSourcePool->First();
     while ( pSource )
@@ -935,7 +815,7 @@ void SfxObjectShell::LoadStyles
         {
             pDest = &pMyPool->Make( pSource->GetName(),
                     pSource->GetFamily(), pSource->GetMask());
-            // Setzen des Parents, der Folgevorlage
+            // Setting of Parents, the next style
         }
         pFound[nFound].pSource = pSource;
         pFound[nFound].pDest = pDest;
@@ -943,10 +823,9 @@ void SfxObjectShell::LoadStyles
         pSource = pSourcePool->Next();
     }
 
-    for ( USHORT i = 0; i < nFound; ++i )
+    for ( sal_uInt16 i = 0; i < nFound; ++i )
     {
         pFound[i].pDest->GetItemSet().PutExtended(pFound[i].pSource->GetItemSet(), SFX_ITEM_DONTCARE, SFX_ITEM_DEFAULT);
-//      pFound[i].pDest->SetHelpId(pFound[i].pSource->GetHelpId());
         if(pFound[i].pSource->HasParentSupport())
             pFound[i].pDest->SetParent(pFound[i].pSource->GetParent());
         if(pFound[i].pSource->HasFollowSupport())
@@ -959,13 +838,12 @@ void SfxObjectShell::LoadStyles
 
 void SfxObjectShell::UpdateFromTemplate_Impl(  )
 
-/*  [Beschreibung]
+/*  [Description]
 
-    Diese interne Methode pr"uft, ob das Dokument aus einem Template
-    erzeugt wurde, und ob dieses neuer ist als das Dokument. Ist dies
-    der Fall, wird der Benutzer gefragt, ob die Vorlagen (StyleSheets)
-    updated werden sollen. Wird dies positiv beantwortet, werden die
-    StyleSheets updated.
+    This internal method checks whether the document was created from a
+    template, and if this is newer than the document. If this is the case,
+    the user is asked if the Templates (StyleSheets) should be updated.
+    If this is answered positively, the StyleSheets are updated.
 */
 
 {
@@ -995,10 +873,10 @@ void SfxObjectShell::UpdateFromTemplate_Impl(  )
 
     if ( aTemplName.getLength() || (aTemplURL.getLength() && !IsReadOnly()) )
     {
-        // try to locate template, first using filename
-        // this must be done because writer global document uses this "great" idea to manage the templates of all parts
-        // in the master document
-        // but it is NOT an error if the template filename points not to a valid file
+        // try to locate template, first using filename this must be done
+        // because writer global document uses this "great" idea to manage
+        // the templates of all parts in the master document but it is NOT
+        // an error if the template filename points not to a valid file
         SfxDocumentTemplates aTempl;
         aTempl.Construct();
         if ( aTemplURL.getLength() )
@@ -1009,7 +887,8 @@ void SfxObjectShell::UpdateFromTemplate_Impl(  )
         }
 
         if( !aFoundName.Len() && aTemplName.getLength() )
-            // if the template filename did not lead to success, try to get a file name for the logical template name
+            // if the template filename did not lead to success,
+            // try to get a file name for the logical template name
             aTempl.GetFull( String(), aTemplName, aFoundName );
     }
 
@@ -1017,13 +896,13 @@ void SfxObjectShell::UpdateFromTemplate_Impl(  )
     {
         // check existence of template storage
         aTemplURL = aFoundName;
-        BOOL bLoad = FALSE;
+        sal_Bool bLoad = sal_False;
 
         // should the document checked against changes in the template ?
         if ( IsQueryLoadTemplate() )
         {
             // load document info of template
-            BOOL bOK = FALSE;
+            sal_Bool bOK = sal_False;
             util::DateTime aTemplDate;
             try
             {
@@ -1040,7 +919,7 @@ void SfxObjectShell::UpdateFromTemplate_Impl(  )
                 if ( aAny >>= aTemplDate )
                 {
                     // get modify date from document info
-                    bOK = TRUE;
+                    bOK = sal_True;
                 }
             }
             catch ( Exception& )
@@ -1057,21 +936,21 @@ void SfxObjectShell::UpdateFromTemplate_Impl(  )
                     // ask user
                     if( bCanUpdateFromTemplate == document::UpdateDocMode::QUIET_UPDATE
                     || bCanUpdateFromTemplate == document::UpdateDocMode::FULL_UPDATE )
-                        bLoad = TRUE;
+                        bLoad = sal_True;
                     else if ( bCanUpdateFromTemplate == document::UpdateDocMode::ACCORDING_TO_CONFIG )
                     {
                         String sMessage( SfxResId( STR_QRYTEMPL_MESSAGE ) );
                         sMessage.SearchAndReplace( String::CreateFromAscii("$(ARG1)"), aTemplName );
                         sfx2::QueryTemplateBox aBox( GetDialogParent(), sMessage );
                         if ( RET_YES == aBox.Execute() )
-                            bLoad = TRUE;
+                            bLoad = sal_True;
                     }
 
                     if( !bLoad )
                     {
                         // user refuses, so don't ask again for this document
-                        SetQueryLoadTemplate(FALSE);
-                        SetModified( TRUE );
+                        SetQueryLoadTemplate(sal_False);
+                        SetModified( sal_True );
                     }
                 }
             }
@@ -1097,63 +976,12 @@ void SfxObjectShell::UpdateFromTemplate_Impl(  )
                     // remember date/time of check
                     xDocProps->setTemplateDate(aTemplDate);
                     // TODO/LATER: new functionality to store document info is required ( didn't work for SO7 XML format )
-//REPLACE					pInfo->Save(xDocStor);
                 }
             }
-/*
-        SfxConfigManager *pCfgMgr = SFX_CFGMANAGER();
-        {
-            SfxConfigManager *pTemplCfg = new SfxConfigManager(aTemplStor, pCfgMgr);
-            SetConfigManager(pTemplCfg);
-            SetTemplateConfig(TRUE);
-
-            // Falls der gerade zerst"orte CfgMgr des Dokuments der
-            // aktive war, pCfgMgr lieber neu holen
-            pCfgMgr = SFX_CFGMANAGER();
-
-            // ggf. den neuen ConfigManager aktivieren
-            if ( this == SfxObjectShell::Current() )
-                pTemplCfg->Activate(pCfgMgr);
-        }
-*/
-        // Template und Template-DocInfo werden nicht mehr gebraucht
-//            delete pTemplInfo;
         }
     }
 }
 
-SfxObjectShellRef MakeObjectShellForOrganizer_Impl( const String& aTargetURL, BOOL bForWriting )
-{
-    // check for own format
-    SfxObjectShellRef xDoc;
-    StreamMode nMode = bForWriting ? SFX_STREAM_READWRITE : SFX_STREAM_READONLY;
-    SfxMedium *pMed = new SfxMedium( aTargetURL, nMode, FALSE, 0 );
-    const SfxFilter* pFilter = NULL;
-    pMed->UseInteractionHandler(TRUE);
-    if( SFX_APP()->GetFilterMatcher().GuessFilter( *pMed, &pFilter ) == ERRCODE_NONE && pFilter && pFilter->IsOwnFormat() )
-    {
-        // create document
-        xDoc = SfxObjectShell::CreateObject( pFilter->GetServiceName(), SFX_CREATE_MODE_ORGANIZER );
-        if ( xDoc.Is() )
-        {
-            // partially load, so don't use DoLoad!
-            xDoc->DoInitNew(0);
-            // TODO/LATER: make sure that we don't use binary templates!
-            if( xDoc->LoadFrom( *pMed ) )
-            {
-                // connect to storage, abandon temp. storage
-                xDoc->DoSaveCompleted( pMed );
-            }
-            else
-                xDoc.Clear();
-        }
-    }
-    else
-        delete pMed;
-
-    return xDoc;
-}
-
 sal_Bool SfxObjectShell::IsHelpDocument() const
 {
     const SfxFilter* pFilter = GetMedium()->GetFilter();
@@ -1208,14 +1036,14 @@ sal_Bool SfxObjectShell::IsUseUserData() const
 void SfxObjectShell::SetQueryLoadTemplate( sal_Bool bNew )
 {
     if ( pImp->bQueryLoadTemplate != bNew )
-        SetModified( TRUE );
+        SetModified( sal_True );
     pImp->bQueryLoadTemplate = bNew;
 }
 
 void SfxObjectShell::SetUseUserData( sal_Bool bNew )
 {
     if ( pImp->bUseUserData != bNew )
-        SetModified( TRUE );
+        SetModified( sal_True );
     pImp->bUseUserData = bNew;
 }
 
@@ -1232,14 +1060,14 @@ sal_Bool SfxObjectShell::IsSaveVersionOnClose() const
 void SfxObjectShell::SetLoadReadonly( sal_Bool bNew )
 {
     if ( pImp->bLoadReadonly != bNew )
-        SetModified( TRUE );
+        SetModified( sal_True );
     pImp->bLoadReadonly = bNew;
 }
 
 void SfxObjectShell::SetSaveVersionOnClose( sal_Bool bNew )
 {
     if ( pImp->bSaveVersionOnClose != bNew )
-        SetModified( TRUE );
+        SetModified( sal_True );
     pImp->bSaveVersionOnClose = bNew;
 }
 
