@@ -133,8 +133,8 @@ uno::Reference<XAccessible>
     // Check wether the given index is valid.
     if (nIndex < 0 || (unsigned long)nIndex >= maVisibleChildren.size())
         throw lang::IndexOutOfBoundsException (
-            ::rtl::OUString::createFromAscii(
-                "no accessible child with index ") + nIndex,
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "no accessible child with index ")) + ::rtl::OUString::valueOf(nIndex),
             mxParent);
 
     return GetChild (maVisibleChildren[nIndex],nIndex);
