@@ -32,7 +32,7 @@
 #include <svx/svdetc.hxx>
 #include <svx/svdmodel.hxx>
 #include <tools/poly.hxx>
-#include <svditer.hxx>
+#include <svx/svditer.hxx>
 #include <svx/svdobj.hxx>
 #include <svx/svdoashp.hxx>
 #include <svl/poolitem.hxx>
@@ -346,11 +346,10 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
         if ( pAny )
             *pAny >>= eProjectionMode;
         ProjectionType eProjectionType( eProjectionMode == drawing::ProjectionMode_PARALLEL ? PR_PARALLEL : PR_PERSPECTIVE );
-
-        // pShape2d Umwandeln in Szene mit 3D Objekt
+        // pShape2d Convert in scenes which include 3D Objects
         E3dDefaultAttributes a3DDefaultAttr;
-        a3DDefaultAttr.SetDefaultLatheCharacterMode( TRUE );
-        a3DDefaultAttr.SetDefaultExtrudeCharacterMode( TRUE );
+        a3DDefaultAttr.SetDefaultLatheCharacterMode( sal_True );
+        a3DDefaultAttr.SetDefaultExtrudeCharacterMode( sal_True );
 
         E3dScene* pScene = new E3dPolyScene( a3DDefaultAttr );
 
@@ -371,7 +370,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
         {
             aSet.Put( XLineStyleItem( XLINE_SOLID ) );
             aSet.Put( XFillStyleItem ( XFILL_NONE ) );
-            aSet.Put( Svx3DDoubleSidedItem( TRUE ) );
+            aSet.Put( Svx3DDoubleSidedItem( sal_True ) );
         }
         else
         {
@@ -411,7 +410,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
             }
             else
             {
-                SdrObject* pNewObj = pNext->ConvertToPolyObj( FALSE, FALSE );
+                SdrObject* pNewObj = pNext->ConvertToPolyObj( sal_False, sal_False );
                 SdrPathObj* pPath = PTR_CAST( SdrPathObj, pNewObj );
                 if ( pPath )
                     aPolyPoly = pPath->GetPathPoly();
@@ -508,7 +507,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
             // then we can change the return value
             pRet = pScene;
 
-            // Kameraeinstellungen, Perspektive ...
+            // Camera settings, Perspective ...
             Camera3D& rCamera = (Camera3D&)pScene->GetCamera();
             const basegfx::B3DRange& rVolume = pScene->GetBoundVolume();
             pScene->NbcSetSnapRect( aSnapRect );
@@ -517,7 +516,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
             double fW = rVolume.getWidth();
             double fH = rVolume.getHeight();
 
-            rCamera.SetAutoAdjustProjection( FALSE );
+            rCamera.SetAutoAdjustProjection( sal_False );
             rCamera.SetViewWindow( -fW / 2, - fH / 2, fW, fH);
             basegfx::B3DPoint aLookAt( 0.0, 0.0, 0.0 );
             basegfx::B3DPoint aCamPos( 0.0, 0.0, 100.0 );
@@ -713,14 +712,6 @@ Rectangle EnhancedCustomShape3d::CalculateNewSnapRect( const SdrObject* pCustomS
     drawing::Direction3D aRotationCenterDefault( 0, 0, 0 );	// default seems to be wrong, a fractional size of shape has to be used!!
     drawing::Direction3D aRotationCenter( GetDirection3D( rGeometryItem, sRotationCenter, aRotationCenterDefault ) );
 
-    // double XCenterInGUnits = rPropSet.GetPropertyValue( DFF_Prop_c3DRotationCenterX, 0 );
-    // double YCenterInGUnits = rPropSet.GetPropertyValue( DFF_Prop_c3DRotationCenterY, 0 );
-
-    // sal_Int32 nRotationXAxisInProz = rPropSet.GetPropertyValue( DFF_Prop_c3DRotationAxisX, 100 );
-    // sal_Int32 nRotationYAxisInProz = rPropSet.GetPropertyValue( DFF_Prop_c3DRotationAxisY, 0 );
-    // sal_Int32 nRotationZAxisInProz = rPropSet.GetPropertyValue( DFF_Prop_c3DRotationAxisZ, 0 );
-
-
     double fXRotate, fYRotate;
     GetRotateAngle( rGeometryItem, fXRotate, fYRotate );
     double fZRotate = - ((SdrObjCustomShape*)pCustomShape)->GetObjectRotation() * F_PI180;
