@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -63,7 +63,7 @@
 #include <comphelper/processfactory.hxx>
 
 #define _IMAPDLG_PRIVATE
-#include "imapdlg.hxx"
+#include "svx/imapdlg.hxx"
 
 #include <svx/dialmgr.hxx>
 #include <svx/dialogs.hrc>
@@ -71,7 +71,7 @@
 #include "imapdlg.hrc"
 #include "imapwnd.hxx"
 #include "imapimp.hxx"
-#include "dlgutil.hxx"
+#include "svx/dlgutil.hxx"
 #include <svx/svdtrans.hxx>
 #include <svx/svdopath.hxx>
 #include <vcl/svapp.hxx>
@@ -109,45 +109,29 @@ inline String GetUnitString( long nVal_100, FieldUnit eFieldUnit, sal_Unicode cS
     return aVal;
 }
 
-/*************************************************************************
-|*
-|* ControllerItem
-|*
-\************************************************************************/
+// ControllerItem
 
-SvxIMapDlgItem::SvxIMapDlgItem( USHORT _nId, SvxIMapDlg& rIMapDlg, SfxBindings& rBindings ) :
+SvxIMapDlgItem::SvxIMapDlgItem( sal_uInt16 _nId, SvxIMapDlg& rIMapDlg, SfxBindings& rBindings ) :
             SfxControllerItem   ( _nId, rBindings ),
             rIMap				( rIMapDlg )
 {
 }
 
-/*************************************************************************
-|*
-|* StateChanged-Methode
-|*
-\************************************************************************/
-
-void SvxIMapDlgItem::StateChanged( USHORT nSID, SfxItemState /*eState*/,
+void SvxIMapDlgItem::StateChanged( sal_uInt16 nSID, SfxItemState /*eState*/,
                                    const SfxPoolItem* pItem )
 {
     if ( ( nSID == SID_IMAP_EXEC ) && pItem )
     {
         const SfxBoolItem* pStateItem = PTR_CAST( SfxBoolItem, pItem );
 
-        DBG_ASSERT( pStateItem || pItem == 0, "SfxBoolItem erwartet");
+        DBG_ASSERT( pStateItem || pItem == 0, "SfxBoolItem expected");
 
-        // Float ggf. disablen
+        // Disable Float if possible
         rIMap.SetExecState( !pStateItem->GetValue() );
     }
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
-SvxIMapDlgChildWindow::SvxIMapDlgChildWindow( Window* _pParent, USHORT nId,
+SvxIMapDlgChildWindow::SvxIMapDlgChildWindow( Window* _pParent, sal_uInt16 nId,
                                               SfxBindings* pBindings,
                                               SfxChildWinInfo* pInfo ) :
             SfxChildWindow( _pParent, nId )
@@ -163,13 +147,6 @@ SvxIMapDlgChildWindow::SvxIMapDlgChildWindow( Window* _pParent, USHORT nId,
     pDlg->Initialize( pInfo );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void SvxIMapDlgChildWindow::UpdateIMapDlg( const Graphic& rGraphic, const ImageMap* pImageMap,
                                            const TargetList* pTargetList, void* pEditingObj )
 {
@@ -178,13 +155,6 @@ void SvxIMapDlgChildWindow::UpdateIMapDlg( const Graphic& rGraphic, const ImageM
         SVXIMAPDLG()->Update( rGraphic, pImageMap, pTargetList, pEditingObj );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 SvxIMapDlg::SvxIMapDlg( SfxBindings *_pBindings, SfxChildWindow *pCW,
                         Window* _pParent, const ResId& rResId ) :
         SfxModelessDialog   ( _pBindings, pCW, _pParent, rResId ),
@@ -198,7 +168,6 @@ SvxIMapDlg::SvxIMapDlg( SfxBindings *_pBindings, SfxChildWindow *pCW,
         maCbbTarget         ( this, SVX_RES( RID_SVXCTL_CBB_TARGET ) ),
         aStbStatus          ( this, WB_BORDER | WB_3DLOOK | WB_LEFT ),
         maImageList         ( SVX_RES( IL_IMAPDLG ) ),
-        maImageListH        ( SVX_RES( ILH_IMAPDLG ) ),
         pCheckObj           ( NULL ),
         aIMapItem           ( SID_IMAP_EXEC, *this, *_pBindings )
 {
@@ -227,7 +196,7 @@ SvxIMapDlg::SvxIMapDlg( SfxBindings *_pBindings, SfxChildWindow *pCW,
     aTbxIMapDlg1.SetOutStyle( aMiscOptions.GetToolboxStyle() );
     aTbxIMapDlg1.SetSizePixel( aTbxIMapDlg1.CalcWindowSizePixel() );
     aTbxIMapDlg1.SetSelectHdl( LINK( this, SvxIMapDlg, TbxClickHdl ) );
-    aTbxIMapDlg1.CheckItem( TBI_SELECT, TRUE );
+    aTbxIMapDlg1.CheckItem( TBI_SELECT, sal_True );
     TbxClickHdl( &aTbxIMapDlg1 );
 
     SetMinOutputSizePixel( aLastSize = GetOutputSizePixel() );
@@ -242,39 +211,25 @@ SvxIMapDlg::SvxIMapDlg( SfxBindings *_pBindings, SfxChildWindow *pCW,
     aEdtText.Disable();
     maFtTarget.Disable();
     maCbbTarget.Disable();
-    pOwnData->bExecState = FALSE;
+    pOwnData->bExecState = sal_False;
 
     Resize();
 
     pOwnData->aTimer.SetTimeout( 100 );
     pOwnData->aTimer.SetTimeoutHdl( LINK( this, SvxIMapDlg, UpdateHdl ) );
 
-    aTbxIMapDlg1.EnableItem( TBI_ACTIVE, FALSE );
-    aTbxIMapDlg1.EnableItem( TBI_MACRO, FALSE );
-    aTbxIMapDlg1.EnableItem( TBI_PROPERTY, FALSE );
+    aTbxIMapDlg1.EnableItem( TBI_ACTIVE, sal_False );
+    aTbxIMapDlg1.EnableItem( TBI_MACRO, sal_False );
+    aTbxIMapDlg1.EnableItem( TBI_PROPERTY, sal_False );
 }
 
-
-/*************************************************************************
-|*
-|* Dtor
-|*
-\************************************************************************/
-
 SvxIMapDlg::~SvxIMapDlg()
 {
-    // URL-Liste loeschen
+    // Delete URL-List
     delete pIMapWnd;
     delete pOwnData;
 }
 
-
-/*************************************************************************
-|*
-|* Resize-Methode
-|*
-\************************************************************************/
-
 void SvxIMapDlg::Resize()
 {
     SfxModelessDialog::Resize();
@@ -287,11 +242,11 @@ void SvxIMapDlg::Resize()
         Size    _aSize( aStbStatus.GetSizePixel() );
         Point   aPoint( 0, aNewSize.Height() - _aSize.Height() );
 
-        // StatusBar positionieren
+        // Position the StatusBar
         aStbStatus.SetPosSizePixel( aPoint, Size( aNewSize.Width(), _aSize.Height() ) );
         aStbStatus.Show();
 
-        // EditWindow positionieren
+        // Position the EditWindow
         _aSize.Width() = aNewSize.Width() - 18;
         _aSize.Height() = aPoint.Y() - pIMapWnd->GetPosPixel().Y() - 6;
         pIMapWnd->SetSizePixel( _aSize );
@@ -300,16 +255,9 @@ void SvxIMapDlg::Resize()
     }
 }
 
-
-/*************************************************************************
-|*
-|* Close-Methode
-|*
-\************************************************************************/
-
-BOOL SvxIMapDlg::Close()
+sal_Bool SvxIMapDlg::Close()
 {
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
 
     if ( aTbxIMapDlg1.IsItemEnabled( TBI_APPLY ) )
     {
@@ -319,12 +267,12 @@ BOOL SvxIMapDlg::Close()
 
         if( nRet == RET_YES )
         {
-            SfxBoolItem aBoolItem( SID_IMAP_EXEC, TRUE );
+            SfxBoolItem aBoolItem( SID_IMAP_EXEC, sal_True );
             GetBindings().GetDispatcher()->Execute(
                 SID_IMAP_EXEC, SFX_CALLMODE_SYNCHRON | SFX_CALLMODE_RECORD, &aBoolItem, 0L );
         }
         else if( nRet == RET_CANCEL )
-            bRet = FALSE;
+            bRet = sal_False;
     }
     else if( pIMapWnd->IsChanged() )
     {
@@ -335,67 +283,34 @@ BOOL SvxIMapDlg::Close()
         if( nRet == RET_YES )
             bRet = DoSave();
         else if( nRet == RET_CANCEL )
-            bRet = FALSE;
+            bRet = sal_False;
     }
 
-    return( bRet ? SfxModelessDialog::Close() : FALSE );
+    return( bRet ? SfxModelessDialog::Close() : sal_False );
 }
 
+// Enabled or disable all Controls
 
-/*************************************************************************
-|*
-|* Enabled oder disabled alle Controls
-|*
-\************************************************************************/
-
-void SvxIMapDlg::SetExecState( BOOL bEnable )
+void SvxIMapDlg::SetExecState( sal_Bool bEnable )
 {
     pOwnData->bExecState = bEnable;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void SvxIMapDlg::SetGraphic( const Graphic& rGraphic )
 {
     pIMapWnd->SetGraphic( rGraphic );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void SvxIMapDlg::SetImageMap( const ImageMap& rImageMap )
 {
     pIMapWnd->SetImageMap( rImageMap );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 const ImageMap& SvxIMapDlg::GetImageMap() const
 {
     return pIMapWnd->GetImageMap();
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void SvxIMapDlg::SetTargetList( const TargetList& rTargetList )
 {
     TargetList	aNewList( rTargetList );
@@ -404,29 +319,15 @@ void SvxIMapDlg::SetTargetList( const TargetList& rTargetList )
 
     maCbbTarget.Clear();
 
-    for( String* pStr = aNewList.First(); pStr; pStr = aNewList.Next() )
-        maCbbTarget.InsertEntry( *pStr );
+    for ( size_t i = 0, n = aNewList.size(); i < n; ++i )
+        maCbbTarget.InsertEntry( *aNewList[ i ] );
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 const TargetList& SvxIMapDlg::GetTargetList() const
 {
     return pIMapWnd->GetTargetList();
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void SvxIMapDlg::Update( const Graphic& rGraphic, const ImageMap* pImageMap,
                          const TargetList* pTargetList, void* pEditingObj )
 {
@@ -439,23 +340,21 @@ void SvxIMapDlg::Update( const Graphic& rGraphic, const ImageMap* pImageMap,
 
     pOwnData->pUpdateEditingObject = pEditingObj;
 
-    // UpdateTargetList loeschen, da diese Methode
-    // vor dem Zuschlagen des Update-Timers noch
-    // mehrmals gerufen werden kann( #46540 )
-    for( String* pStr = pOwnData->aUpdateTargetList.First(); pStr; pStr = pOwnData->aUpdateTargetList.Next() )
-        delete pStr;
-    pOwnData->aUpdateTargetList.Clear();
+    // Delete UpdateTargetList, because this method can still be called several
+    // times before the update timer is turned on
+    for ( size_t i = 0, n = pOwnData->aUpdateTargetList.size(); i < n; ++i )
+        delete pOwnData->aUpdateTargetList[ i ];
+    pOwnData->aUpdateTargetList.clear();
 
-    // TargetListe muss kopiert werden, da sie im
-    // Besitz des Aufrufers ist und von ihm nach diesem
-    // Aufruf sofort geloescht werden kann;
-    // die kopierte Liste wird im Handler wieder geloescht
+    // TargetList must be copied, since it is owned by the caller and can be 
+    // deleted immediately after this call the copied list will be deleted 
+    // again in the handler
     if( pTargetList )
     {
         TargetList aTargetList( *pTargetList );
 
-        for( String* pStr = aTargetList.First(); pStr; pStr = aTargetList.Next() )
-            pOwnData->aUpdateTargetList.Insert( new String( *pStr ) );
+        for ( size_t i = 0, n = aTargetList.size(); i < n; ++i )
+            pOwnData->aUpdateTargetList.push_back( new String( *aTargetList[ i ] ) );
     }
 
     pOwnData->aTimer.Start();
@@ -467,22 +366,18 @@ void SvxIMapDlg::KeyInput( const KeyEvent& rKEvt )
         SfxModelessDialog::KeyInput( rKEvt );
 }
 
-/*************************************************************************
-|*
-|* Click-Hdl fuer ToolBox
-|*
-\************************************************************************/
+// Click-handler for ToolBox
 
 IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
 {
-    USHORT nNewItemId = pTbx->GetCurItemId();
+    sal_uInt16 nNewItemId = pTbx->GetCurItemId();
 
     switch( pTbx->GetCurItemId() )
     {
         case( TBI_APPLY ):
         {
             URLLoseFocusHdl( NULL );
-            SfxBoolItem aBoolItem( SID_IMAP_EXEC, TRUE );
+            SfxBoolItem aBoolItem( SID_IMAP_EXEC, sal_True );
             GetBindings().GetDispatcher()->Execute(
                 SID_IMAP_EXEC, SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD, &aBoolItem, 0L );
         }
@@ -498,8 +393,8 @@ IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
 
         case( TBI_SELECT ):
         {
-            pTbx->CheckItem( nNewItemId, TRUE );
-            pIMapWnd->SetEditMode( TRUE );
+            pTbx->CheckItem( nNewItemId, sal_True );
+            pIMapWnd->SetEditMode( sal_True );
             if( pTbx->IsKeyEvent() )
             {
                 if((pTbx->GetKeyModifier() & KEY_MOD1) != 0)
@@ -512,7 +407,7 @@ IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
 
         case( TBI_RECT ):
         {
-            pTbx->CheckItem( nNewItemId, TRUE );
+            pTbx->CheckItem( nNewItemId, sal_True );
             pIMapWnd->SetObjKind( OBJ_RECT );
             if( pTbx->IsKeyEvent() && ((pTbx->GetKeyModifier() & KEY_MOD1) != 0) )
             {
@@ -524,7 +419,7 @@ IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
 
         case( TBI_CIRCLE ):
         {
-            pTbx->CheckItem( nNewItemId, TRUE );
+            pTbx->CheckItem( nNewItemId, sal_True );
             pIMapWnd->SetObjKind( OBJ_CIRC );
             if( pTbx->IsKeyEvent() && ((pTbx->GetKeyModifier() & KEY_MOD1) != 0) )
             {
@@ -536,7 +431,7 @@ IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
 
         case( TBI_POLY ):
         {
-            pTbx->CheckItem( nNewItemId, TRUE );
+            pTbx->CheckItem( nNewItemId, sal_True );
             pIMapWnd->SetObjKind( OBJ_POLY );
             if( pTbx->IsKeyEvent() && ((pTbx->GetKeyModifier() & KEY_MOD1) != 0) )
             {
@@ -548,7 +443,7 @@ IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
 
         case( TBI_FREEPOLY ):
         {
-            pTbx->CheckItem( nNewItemId, TRUE );
+            pTbx->CheckItem( nNewItemId, sal_True );
             pIMapWnd->SetObjKind( OBJ_FREEFILL );
             if( pTbx->IsKeyEvent() && ((pTbx->GetKeyModifier() & KEY_MOD1) != 0) )
             {
@@ -561,7 +456,7 @@ IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
         case( TBI_ACTIVE ):
         {
             URLLoseFocusHdl( NULL );
-            BOOL bNewState = !pTbx->IsItemChecked( TBI_ACTIVE );
+            sal_Bool bNewState = !pTbx->IsItemChecked( TBI_ACTIVE );
             pTbx->CheckItem( TBI_ACTIVE, bNewState );
             pIMapWnd->SetCurrentObjState( !bNewState );
         }
@@ -614,13 +509,6 @@ IMPL_LINK( SvxIMapDlg, TbxClickHdl, ToolBox*, pTbx )
     return 0;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void SvxIMapDlg::DoOpen()
 {
        ::sfx2::FileDialogHelper aDlg(
@@ -662,14 +550,7 @@ void SvxIMapDlg::DoOpen()
     }
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
-BOOL SvxIMapDlg::DoSave()
+sal_Bool SvxIMapDlg::DoSave()
 {
        ::sfx2::FileDialogHelper aDlg(
         com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_SIMPLE, 0 );
@@ -679,7 +560,7 @@ BOOL SvxIMapDlg::DoSave()
     const String	aNCSAFilter( DEFINE_CONST_UNICODE( IMAP_NCSA_FILTER ) );
     SdrModel*		pModel = pIMapWnd->GetSdrModel();
     const sal_Bool bChanged = pModel->IsChanged();
-    BOOL			bRet = false;
+    sal_Bool			bRet = false;
 
     aDlg.AddFilter( aCERNFilter, DEFINE_CONST_UNICODE( IMAP_CERN_TYPE ) );
     aDlg.AddFilter( aNCSAFilter, DEFINE_CONST_UNICODE( IMAP_NCSA_TYPE ) );
@@ -692,7 +573,7 @@ BOOL SvxIMapDlg::DoSave()
     {
         const String	aFilter( aDlg.GetCurrentFilter() );
         String			aExt;
-        ULONG			nFormat;
+        sal_uIntPtr			nFormat;
 
         if ( aFilter == aBinFilter )
         {
@@ -711,14 +592,14 @@ BOOL SvxIMapDlg::DoSave()
         }
         else
         {
-            return FALSE;
+            return sal_False;
         }
 
         INetURLObject aURL( aDlg.GetPath() );
 
         if( aURL.GetProtocol() == INET_PROT_NOT_VALID )
         {
-            DBG_ERROR( "invalid URL" );
+            OSL_FAIL( "invalid URL" );
         }
         else
         {
@@ -735,7 +616,7 @@ BOOL SvxIMapDlg::DoSave()
 
                 delete pOStm;
                 pModel->SetChanged( bChanged );
-                bRet = TRUE;
+                bRet = sal_True;
             }
         }
     }
@@ -743,13 +624,6 @@ BOOL SvxIMapDlg::DoSave()
     return bRet;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, InfoHdl, IMapWindow*, pWnd )
 {
     String				aStr;
@@ -771,10 +645,10 @@ IMPL_LINK( SvxIMapDlg, InfoHdl, IMapWindow*, pWnd )
 
     if ( !rInfo.bOneMarked )
     {
-        aTbxIMapDlg1.CheckItem( TBI_ACTIVE, FALSE );
-        aTbxIMapDlg1.EnableItem( TBI_ACTIVE, FALSE );
-        aTbxIMapDlg1.EnableItem( TBI_MACRO, FALSE );
-        aTbxIMapDlg1.EnableItem( TBI_PROPERTY, FALSE );
+        aTbxIMapDlg1.CheckItem( TBI_ACTIVE, sal_False );
+        aTbxIMapDlg1.EnableItem( TBI_ACTIVE, sal_False );
+        aTbxIMapDlg1.EnableItem( TBI_MACRO, sal_False );
+        aTbxIMapDlg1.EnableItem( TBI_PROPERTY, sal_False );
         aStbStatus.SetItemText( 1, aStr );
 
         aFtURL.Disable();
@@ -789,10 +663,10 @@ IMPL_LINK( SvxIMapDlg, InfoHdl, IMapWindow*, pWnd )
     }
     else
     {
-        aTbxIMapDlg1.EnableItem( TBI_ACTIVE, TRUE );
+        aTbxIMapDlg1.EnableItem( TBI_ACTIVE, sal_True );
         aTbxIMapDlg1.CheckItem( TBI_ACTIVE, !rInfo.bActivated );
-        aTbxIMapDlg1.EnableItem( TBI_MACRO, TRUE );
-        aTbxIMapDlg1.EnableItem( TBI_PROPERTY, TRUE );
+        aTbxIMapDlg1.EnableItem( TBI_MACRO, sal_True );
+        aTbxIMapDlg1.EnableItem( TBI_PROPERTY, sal_True );
 
         aFtURL.Enable();
         maURLBox.Enable();
@@ -818,12 +692,6 @@ IMPL_LINK( SvxIMapDlg, InfoHdl, IMapWindow*, pWnd )
     return 0;
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, MousePosHdl, IMapWindow*, pWnd )
 {
     String aStr;
@@ -841,12 +709,6 @@ IMPL_LINK( SvxIMapDlg, MousePosHdl, IMapWindow*, pWnd )
     return 0L;
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, GraphSizeHdl, IMapWindow*, pWnd )
 {
     String aStr;
@@ -864,12 +726,6 @@ IMPL_LINK( SvxIMapDlg, GraphSizeHdl, IMapWindow*, pWnd )
     return 0L;
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, URLModifyHdl, void*, EMPTYARG )
 {
     NotifyInfo	aNewInfo;
@@ -883,13 +739,6 @@ IMPL_LINK( SvxIMapDlg, URLModifyHdl, void*, EMPTYARG )
     return 0;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, URLLoseFocusHdl, void*, EMPTYARG )
 {
     NotifyInfo		aNewInfo;
@@ -918,13 +767,6 @@ IMPL_LINK( SvxIMapDlg, URLLoseFocusHdl, void*, EMPTYARG )
     return 0;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, UpdateHdl, Timer*, EMPTYARG )
 {
     pOwnData->aTimer.Stop();
@@ -943,36 +785,28 @@ IMPL_LINK( SvxIMapDlg, UpdateHdl, Timer*, EMPTYARG )
         SetTargetList( pOwnData->aUpdateTargetList );
         SetEditingObject( pOwnData->pUpdateEditingObject );
 
-        // Nach Wechsel => default Selektion
-        aTbxIMapDlg1.CheckItem( TBI_SELECT, TRUE );
-        pIMapWnd->SetEditMode( TRUE );
+        // After changes => default selection
+        aTbxIMapDlg1.CheckItem( TBI_SELECT, sal_True );
+        pIMapWnd->SetEditMode( sal_True );
     }
 
-    // die in der Update-Methode kopierte Liste wieder loeschen
-    for( String* pStr = pOwnData->aUpdateTargetList.First(); pStr; pStr = pOwnData->aUpdateTargetList.Next() )
-        delete pStr;
-
-    pOwnData->aUpdateTargetList.Clear();
+    // Delete the copied list again in the Update method 
+    for ( size_t i = 0, n = pOwnData->aUpdateTargetList.size(); i < n; ++i )
+        delete pOwnData->aUpdateTargetList[ i ];
+    pOwnData->aUpdateTargetList.clear();
 
     GetBindings().Invalidate( SID_IMAP_EXEC );
 
     return 0L;
 }
 
-
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, StateHdl, IMapWindow*, pWnd )
 {
     const SdrObject*	pObj = pWnd->GetSelectedSdrObject();
     const SdrModel*		pModel = pWnd->GetSdrModel();
     const SdrView*		pView = pWnd->GetSdrView();
-    const BOOL			bPolyEdit = ( pObj != NULL ) && pObj->ISA( SdrPathObj );
-    const BOOL			bDrawEnabled = !( bPolyEdit && aTbxIMapDlg1.IsItemChecked( TBI_POLYEDIT ) );
+    const sal_Bool			bPolyEdit = ( pObj != NULL ) && pObj->ISA( SdrPathObj );
+    const sal_Bool			bDrawEnabled = !( bPolyEdit && aTbxIMapDlg1.IsItemChecked( TBI_POLYEDIT ) );
 
     aTbxIMapDlg1.EnableItem( TBI_APPLY, pOwnData->bExecState && pWnd->IsChanged() );
 
@@ -994,7 +828,7 @@ IMPL_LINK( SvxIMapDlg, StateHdl, IMapWindow*, pWnd )
 
     if ( bPolyEdit )
     {
-        USHORT nId = 0;
+        sal_uInt16 nId = 0;
 
         switch( pWnd->GetPolyEditMode() )
         {
@@ -1005,25 +839,19 @@ IMPL_LINK( SvxIMapDlg, StateHdl, IMapWindow*, pWnd )
             break;
         }
 
-        aTbxIMapDlg1.CheckItem( nId, TRUE );
+        aTbxIMapDlg1.CheckItem( nId, sal_True );
     }
     else
     {
-        aTbxIMapDlg1.CheckItem( TBI_POLYEDIT, FALSE );
-        aTbxIMapDlg1.CheckItem( TBI_POLYMOVE, TRUE );
-        aTbxIMapDlg1.CheckItem( TBI_POLYINSERT, FALSE );
+        aTbxIMapDlg1.CheckItem( TBI_POLYEDIT, sal_False );
+        aTbxIMapDlg1.CheckItem( TBI_POLYMOVE, sal_True );
+        aTbxIMapDlg1.CheckItem( TBI_POLYINSERT, sal_False );
         pWnd->SetPolyEditMode( 0 );
     }
 
     return 0L;
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 IMPL_LINK( SvxIMapDlg, MiscHdl, void*, EMPTYARG )
 {
        SvtMiscOptions aMiscOptions;
@@ -1034,9 +862,7 @@ IMPL_LINK( SvxIMapDlg, MiscHdl, void*, EMPTYARG )
 
 void SvxIMapDlg::ApplyImageList()
 {
-    bool bHighContrast = GetSettings().GetStyleSettings().GetHighContrastMode();
-
-    ImageList& rImgLst = bHighContrast ? maImageListH : maImageList;
+    ImageList& rImgLst = maImageList;
 
     aTbxIMapDlg1.SetImageList( rImgLst );
 }
