@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,7 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svx.hxx"
 
-#include "fmresids.hrc"
+#include "svx/fmresids.hrc"
 #include "fmexpl.hrc"
 #include "fmexpl.hxx"
 
@@ -45,7 +45,7 @@
 
 #include "fmprop.hrc"
 #include <svx/dialmgr.hxx>
-#include "svditer.hxx"
+#include "svx/svditer.hxx"
 #include <svx/svdouno.hxx>
 #include <fmundo.hxx>
 #include <svx/svdobj.hxx>
@@ -210,6 +210,43 @@ FmEntryDataList::~FmEntryDataList()
     DBG_DTOR(FmEntryDataList,NULL);
 }
 
+//------------------------------------------------------------------------
+FmEntryData* FmEntryDataList::remove( FmEntryData* pItem )
+{
+    for ( FmEntryDataBaseList::iterator it = maEntryDataList.begin();
+          it < maEntryDataList.end();
+          ++it
+        )
+    {
+        if ( *it == pItem )
+        {
+            maEntryDataList.erase( it );
+            break;
+        }
+    }
+    return pItem;
+}
+
+//------------------------------------------------------------------------
+void FmEntryDataList::insert( FmEntryData* pItem, size_t Index )
+{
+    if ( Index < maEntryDataList.size() )
+    {
+        FmEntryDataBaseList::iterator it = maEntryDataList.begin();
+        ::std::advance( it, Index );
+        maEntryDataList.insert( it, pItem );
+    }
+    else
+        maEntryDataList.push_back( pItem );
+}
+
+//------------------------------------------------------------------------
+void FmEntryDataList::clear()
+{
+    for ( size_t i = 0, n = maEntryDataList.size(); i < n; ++i )
+        delete maEntryDataList[ i ];
+    maEntryDataList.clear();
+}
 
 //========================================================================
 // class FmEntryData
@@ -252,16 +289,15 @@ FmEntryData::FmEntryData( const FmEntryData& rEntryData )
     pChildList = new FmEntryDataList();
     aText = rEntryData.GetText();
     m_aNormalImage = rEntryData.GetNormalImage();
-    m_aHCImage = rEntryData.GetHCImage();
     pParent = rEntryData.GetParent();
 
     FmEntryData* pChildData;
-    sal_uInt32 nEntryCount = rEntryData.GetChildList()->Count();
-    for( sal_uInt32 i=0; i<nEntryCount; i++ )
+    size_t nEntryCount = rEntryData.GetChildList()->size();
+    for( size_t i = 0; i < nEntryCount; i++ )
     {
-        pChildData = rEntryData.GetChildList()->GetObject(i);
+        pChildData = rEntryData.GetChildList()->at( i );
         FmEntryData* pNewChildData = pChildData->Clone();
-        pChildList->Insert( pNewChildData, LIST_APPEND );
+        pChildList->insert( pNewChildData, size_t(-1) );
     }
 
     m_xNormalizedIFace = rEntryData.m_xNormalizedIFace;
@@ -273,13 +309,7 @@ FmEntryData::FmEntryData( const FmEntryData& rEntryData )
 void FmEntryData::Clear()
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmEntryData::Clear" );
-    for (;;)
-    {
-        FmEntryData* pEntryData = GetChildList()->Remove(ULONG(0));
-        if (pEntryData == NULL)
-            break;
-        delete pEntryData;
-    }
+    GetChildList()->clear();
 }
 
 //------------------------------------------------------------------------
@@ -317,16 +347,19 @@ sal_Bool FmEntryData::IsEqualWithoutChilds( FmEntryData* pEntryData )
 TYPEINIT1( FmFormData, FmEntryData );
 DBG_NAME(FmFormData);
 //------------------------------------------------------------------------
-FmFormData::FmFormData( const Reference< XForm >& _rxForm, const ImageList& _rNormalImages, const ImageList& _rHCImages, FmFormData* _pParent )
-    :FmEntryData( _pParent, _rxForm )
-    ,m_xForm( _rxForm )
+FmFormData::FmFormData(
+    const Reference< XForm >& _rxForm,
+    const ImageList& _rNormalImages,
+    FmFormData* _pParent
+)
+:   FmEntryData( _pParent, _rxForm ),
+    m_xForm( _rxForm )
 {
     DBG_CTOR(FmEntryData,NULL);
     //////////////////////////////////////////////////////////////////////
     // Images setzen
 
     m_aNormalImage = _rNormalImages.GetImage( RID_SVXIMG_FORM );
-    m_aHCImage = _rHCImages.GetImage( RID_SVXIMG_FORM );
 
     //////////////////////////////////////////////////////////////////////
     // Titel setzen
@@ -384,16 +417,19 @@ sal_Bool FmFormData::IsEqualWithoutChilds( FmEntryData* pEntryData )
 TYPEINIT1( FmControlData, FmEntryData );
 DBG_NAME(FmControlData);
 //------------------------------------------------------------------------
-FmControlData::FmControlData( const Reference< XFormComponent >& _rxComponent, const ImageList& _rNormalImages, const ImageList& _rHCImages, FmFormData* _pParent )
-    :FmEntryData( _pParent, _rxComponent )
-    ,m_xFormComponent( _rxComponent )
+FmControlData::FmControlData(
+    const Reference< XFormComponent >& _rxComponent,
+    const ImageList& _rNormalImages,
+    FmFormData* _pParent
+)
+:   FmEntryData( _pParent, _rxComponent ),
+    m_xFormComponent( _rxComponent )
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmControlData::FmControlData" );
     DBG_CTOR(FmControlData,NULL);
     //////////////////////////////////////////////////////////////////////
     // Images setzen
     m_aNormalImage = GetImage( _rNormalImages );
-    m_aHCImage = GetImage( _rHCImages );
 
     //////////////////////////////////////////////////////////////////////
     // Titel setzen
@@ -554,7 +590,10 @@ sal_Bool FmControlData::IsEqualWithoutChilds( FmEntryData* pEntryData )
 }
 
 //------------------------------------------------------------------------
-void FmControlData::ModelReplaced( const Reference< XFormComponent >& _rxNew, const ImageList& _rNormalImages, const ImageList& _rHCImages )
+void FmControlData::ModelReplaced(
+    const Reference< XFormComponent >& _rxNew,
+    const ImageList& _rNormalImages
+)
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmControlData::ModelReplaced" );
     m_xFormComponent = _rxNew;
@@ -562,7 +601,6 @@ void FmControlData::ModelReplaced( const Reference< XFormComponent >& _rxNew, co
 
     // Images neu setzen
     m_aNormalImage = GetImage( _rNormalImages );
-    m_aHCImage = GetImage( _rHCImages );
 }
 
 //............................................................................
