@@ -29,9 +29,9 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svx.hxx"
 
-#include "fmresids.hrc"
+#include "svx/fmresids.hrc"
 #include "svx/fmtools.hxx"
-#include "fmsrccfg.hxx"
+#include "svx/fmsrccfg.hxx"
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include <tools/wldcrd.hxx>
@@ -58,7 +58,7 @@
 
 #include "fmprop.hrc"
 #include "fmservs.hxx"
-#include "fmsrcimp.hxx"
+#include "svx/fmsrcimp.hxx"
 #include <svx/fmsearch.hxx>
 
 #include <comphelper/numbers.hxx>
@@ -77,11 +77,6 @@ using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::beans;
 using namespace ::svxform;
 
-// ***************************************************************************************************
-
-// ***************************************************************************************************
-
-SV_IMPL_OBJARR(SvInt32Array, sal_Int32);
 
 //========================================================================
 // = FmSearchThread
@@ -164,7 +159,7 @@ void FmRecordCountListener::NotifyCurrentCount()
     if (m_lnkWhoWantsToKnow.IsSet())
     {
         DBG_ASSERT(m_xListening.is(), "FmRecordCountListener::NotifyCurrentCount : I have no propset ... !?");
-        void* pTheCount = (void*)::comphelper::getINT32(m_xListening->getPropertyValue(FM_PROP_ROWCOUNT));
+        void* pTheCount = (void*)(sal_IntPtr)::comphelper::getINT32(m_xListening->getPropertyValue(FM_PROP_ROWCOUNT));
         m_lnkWhoWantsToKnow.Call(pTheCount);
     }
 }
@@ -218,8 +213,8 @@ CheckBoxWrapper::CheckBoxWrapper(const Reference< ::com::sun::star::awt::XCheckB
 {
     switch ((TriState)m_xBox->getState())
     {
-        case STATE_NOCHECK: return rtl::OUString::createFromAscii("0");
-        case STATE_CHECK: return rtl::OUString::createFromAscii("1");
+        case STATE_NOCHECK: return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("0"));
+        case STATE_CHECK: return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("1"));
         default: break;
     }
     return rtl::OUString();
@@ -253,31 +248,31 @@ sal_Bool FmSearchEngine::MoveCursor()
             else
                 m_xSearchCursor.previous();
     }
-    catch(::com::sun::star::sdbc::SQLException  e)
+    catch(::com::sun::star::sdbc::SQLException const& e)
     {
 #if OSL_DEBUG_LEVEL > 0
         String sDebugMessage;
         sDebugMessage.AssignAscii("FmSearchEngine::MoveCursor : catched a DatabaseException (");
         sDebugMessage += (const sal_Unicode*)e.SQLState;
         sDebugMessage.AppendAscii(") !");
-        DBG_ERROR(ByteString(sDebugMessage, RTL_TEXTENCODING_ASCII_US).GetBuffer());
+        OSL_FAIL(ByteString(sDebugMessage, RTL_TEXTENCODING_ASCII_US).GetBuffer());
 #endif
         bSuccess = sal_False;
     }
-    catch(Exception  e)
+    catch(Exception const& e)
     {
 #if OSL_DEBUG_LEVEL > 0
         UniString sDebugMessage;
         sDebugMessage.AssignAscii("FmSearchEngine::MoveCursor : catched an Exception (");
         sDebugMessage += (const sal_Unicode*)e.Message;
         sDebugMessage.AppendAscii(") !");
-        DBG_ERROR(ByteString(sDebugMessage, RTL_TEXTENCODING_ASCII_US).GetBuffer());
+        OSL_FAIL(ByteString(sDebugMessage, RTL_TEXTENCODING_ASCII_US).GetBuffer());
 #endif
         bSuccess = sal_False;
     }
     catch(...)
     {
-        DBG_ERROR("FmSearchEngine::MoveCursor : catched an unknown Exception !");
+        OSL_FAIL("FmSearchEngine::MoveCursor : catched an unknown Exception !");
         bSuccess = sal_False;
     }
 
@@ -844,7 +839,7 @@ void FmSearchEngine::Init(const ::rtl::OUString& sVisibleFields)
     // analyze the fields
     // additionally, create the mapping: because the list of used columns can be shorter than the list
     // of columns of the cursor, we need a mapping: "used column numer n" -> "cursor column m"
-    m_arrFieldMapping.Remove(0, m_arrFieldMapping.Count());
+    m_arrFieldMapping.clear();
 
     // important: The case of the columns does not need to be exact - for instance:
     // - a user created a form which works on a table, for which the driver returns a column name "COLUMN"
@@ -852,7 +847,7 @@ void FmSearchEngine::Init(const ::rtl::OUString& sVisibleFields)
     // - a control in the form is bound to "column" - not the different case
     // In such a scenario, the form and the field would work okay, but we here need to case for the different case
     // explicitly
-    // 2003-01-09 - #i8755# - fs@openoffice.org
+    // #i8755#
 
     // so first of all, check if the database handles identifiers case sensitive
     Reference< XConnection > xConn;
@@ -907,13 +902,13 @@ void FmSearchEngine::Init(const ::rtl::OUString& sVisibleFields)
             }
             // set the field selection back to the first
             pFieldNames = seqFieldNames.getArray();;
-            DBG_ASSERT(nFoundIndex != -1, "FmSearchEngine::Init : Es wurden ungueltige Feldnamen angegeben !");
-            m_arrFieldMapping.Insert(nFoundIndex, m_arrFieldMapping.Count());
+            DBG_ASSERT(nFoundIndex != -1, "FmSearchEngine::Init : Invalid field name were given !");
+            m_arrFieldMapping.push_back(nFoundIndex);
         }
     }
     catch(Exception&)
     {
-        DBG_ERROR("Exception occured!");
+        OSL_FAIL("Exception occurred!");
     }
 
 }
@@ -1011,19 +1006,19 @@ void FmSearchEngine::SearchNextImpl()
             switch (m_nPosition)
             {
                 case MATCHING_ANYWHERE :
-                    strSearchExpression = ::rtl::OUString::createFromAscii("*") + strSearchExpression
-                    + ::rtl::OUString::createFromAscii("*");
+                    strSearchExpression = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("*")) + strSearchExpression
+                    + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("*"));
                     break;
                 case MATCHING_BEGINNING :
-                    strSearchExpression = strSearchExpression + ::rtl::OUString::createFromAscii("*");
+                    strSearchExpression = strSearchExpression + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("*"));
                     break;
                 case MATCHING_END :
-                    strSearchExpression = ::rtl::OUString::createFromAscii("*") + strSearchExpression;
+                    strSearchExpression = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("*")) + strSearchExpression;
                     break;
                 case MATCHING_WHOLETEXT :
                     break;
                 default :
-                    DBG_ERROR("FmSearchEngine::SearchNextImpl() : die Methoden-Listbox duerfte nur 4 Eintraege enthalten ...");
+                    OSL_FAIL("FmSearchEngine::SearchNextImpl() : die Methoden-Listbox duerfte nur 4 Eintraege enthalten ...");
             }
         }
     }
@@ -1269,18 +1264,21 @@ void FmSearchEngine::RebuildUsedFields(sal_Int32 nFieldIndex, sal_Bool bForce)
         return;
     // (da ich keinen Wechsel des Iterators von aussen zulasse, heisst selber ::com::sun::star::sdbcx::Index auch immer selbe Spalte, also habe ich nix zu tun)
 
-    DBG_ASSERT((nFieldIndex >= -1) && (nFieldIndex<m_arrFieldMapping.Count()), "FmSearchEngine::RebuildUsedFields : nFieldIndex ist ungueltig !");
+    DBG_ASSERT((nFieldIndex == -1) ||
+               ((nFieldIndex >= 0) &&
+                (static_cast<size_t>(nFieldIndex) < m_arrFieldMapping.size())),
+            "FmSearchEngine::RebuildUsedFields : nFieldIndex is invalid!");
     // alle Felder, die ich durchsuchen muss, einsammeln
     m_arrUsedFields.clear();
     if (nFieldIndex == -1)
     {
         Reference< ::com::sun::star::container::XIndexAccess >  xFields;
-        for (sal_uInt16 i=0; i<m_arrFieldMapping.Count(); ++i)
+        for (size_t i=0; i<m_arrFieldMapping.size(); ++i)
         {
             Reference< ::com::sun::star::sdbcx::XColumnsSupplier >  xSupplyCols(IFACECAST(m_xSearchCursor), UNO_QUERY);
             DBG_ASSERT(xSupplyCols.is(), "FmSearchEngine::RebuildUsedFields : invalid cursor (no columns supplier) !");
             xFields = Reference< ::com::sun::star::container::XIndexAccess > (xSupplyCols->getColumns(), UNO_QUERY);
-            BuildAndInsertFieldInfo(xFields, m_arrFieldMapping.GetObject(i));
+            BuildAndInsertFieldInfo(xFields, m_arrFieldMapping[i]);
         }
     }
     else
@@ -1289,7 +1287,7 @@ void FmSearchEngine::RebuildUsedFields(sal_Int32 nFieldIndex, sal_Bool bForce)
         Reference< ::com::sun::star::sdbcx::XColumnsSupplier >  xSupplyCols(IFACECAST(m_xSearchCursor), UNO_QUERY);
         DBG_ASSERT(xSupplyCols.is(), "FmSearchEngine::RebuildUsedFields : invalid cursor (no columns supplier) !");
         xFields = Reference< ::com::sun::star::container::XIndexAccess > (xSupplyCols->getColumns(), UNO_QUERY);
-        BuildAndInsertFieldInfo(xFields, m_arrFieldMapping.GetObject((sal_uInt16)nFieldIndex));
+        BuildAndInsertFieldInfo(xFields, m_arrFieldMapping[static_cast< size_t >(nFieldIndex)]);
     }
 
     m_nCurrentFieldIndex = nFieldIndex;
