@@ -47,11 +47,10 @@
 #include <sfx2/bindings.hxx>
 #include <sfx2/dispatch.hxx>
 #include <basic/sbuno.hxx>
-#include <sfx2/macrconf.hxx>
 #include <basic/sbx.hxx>
 #include "fmitems.hxx"
 #include "fmobj.hxx"
-#include "svditer.hxx"
+#include "svx/svditer.hxx"
 #include <svx/svdpagv.hxx>
 #include <svx/svdogrp.hxx>
 #include <svx/fmview.hxx>
@@ -77,7 +76,7 @@
 #include <vcl/stdtext.hxx>
 #include <svx/fmglob.hxx>
 #include <svx/sdrpagewindow.hxx>
-#include "sdrpaintwindow.hxx"
+#include "svx/sdrpaintwindow.hxx"
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -126,8 +125,6 @@ void FmFormView::Init()
         // This means this is a newly created document. This means, we want to have it in design
         // mode by default (though a newly created model returns true for GetOpenInDesignMode).
         // We _want_ to have this because it makes a lot of hacks following the original fix
-        // for #94595# unnecessary
-        // #96399# - 2002-10-11 - fs@openoffice.org
         DBG_ASSERT( !bInitDesignMode, "FmFormView::Init: doesn't the model default to FALSE anymore?" );
             // if this asserts, either the on-contruction default in the model has changed (then this here
             // may not be necessary anymore), or we're not dealing with a new document ....
@@ -140,9 +137,7 @@ void FmFormView::Init()
         const SfxPoolItem *pItem=0;
         if ( pObjShell->GetMedium()->GetItemSet()->GetItemState( SID_COMPONENTDATA, sal_False, &pItem ) == SFX_ITEM_SET )
         {
-            Sequence< PropertyValue > aSeq;
-            ( ((SfxUnoAnyItem*)pItem)->GetValue() ) >>= aSeq;
-            ::comphelper::NamedValueCollection aComponentData( aSeq );
+            ::comphelper::NamedValueCollection aComponentData( ((SfxUnoAnyItem*)pItem)->GetValue() );
             bInitDesignMode = aComponentData.getOrDefault( "ApplyFormDesignMode", bInitDesignMode );
         }
     }
@@ -190,7 +185,7 @@ void FmFormView::MarkListHasChanged()
                 pImpl->m_xWindow->removeFocusListener(pImpl);
                 pImpl->m_xWindow = NULL;
             }
-            SetMoveOutside(FALSE);
+            SetMoveOutside(sal_False);
             //OLMRefreshAllIAOManagers();
         }
 
@@ -507,9 +502,9 @@ void FmFormView::EndCompleteRedraw( SdrPaintWindow& rPaintWindow, bool bPaintFor
 }
 
 // -----------------------------------------------------------------------------
-BOOL FmFormView::KeyInput(const KeyEvent& rKEvt, Window* pWin)
+sal_Bool FmFormView::KeyInput(const KeyEvent& rKEvt, Window* pWin)
 {
-    BOOL bDone = FALSE;
+    sal_Bool bDone = sal_False;
     const KeyCode& rKeyCode = rKEvt.GetKeyCode();
     if  (   IsDesignMode()
         &&	rKeyCode.GetCode() == KEY_RETURN
@@ -532,10 +527,10 @@ BOOL FmFormView::KeyInput(const KeyEvent& rKEvt, Window* pWin)
                     pImpl->m_xWindow = xWindow;
                     // add as listener to get notified when ESC will be pressed inside the grid
                     pImpl->m_xWindow->addFocusListener(pImpl);
-                    SetMoveOutside(TRUE);
+                    SetMoveOutside(sal_True);
                     //OLMRefreshAllIAOManagers();
                     xWindow->setFocus();
-                    bDone = TRUE;
+                    bDone = sal_True;
                 }
             }
         }
@@ -568,9 +563,9 @@ sal_Bool FmFormView::checkUnMarkAll(const Reference< XInterface >& _xSource)
 }
 
 // -----------------------------------------------------------------------------
-BOOL FmFormView::MouseButtonDown( const MouseEvent& _rMEvt, Window* _pWin )
+sal_Bool FmFormView::MouseButtonDown( const MouseEvent& _rMEvt, Window* _pWin )
 {
-    BOOL bReturn = E3dView::MouseButtonDown( _rMEvt, _pWin );
+    sal_Bool bReturn = E3dView::MouseButtonDown( _rMEvt, _pWin );
 
     if ( pFormShell && pFormShell->GetImpl() )
     {
@@ -607,7 +602,7 @@ FmFormObj* FmFormView::getMarkedGrid() const
 // -----------------------------------------------------------------------------
 void FmFormView::createControlLabelPair( OutputDevice* _pOutDev, sal_Int32 _nXOffsetMM, sal_Int32 _nYOffsetMM,
     const Reference< XPropertySet >& _rxField, const Reference< XNumberFormats >& _rxNumberFormats,
-    sal_uInt16 _nControlObjectID, const ::rtl::OUString& _rFieldPostfix, UINT32 _nInventor, UINT16 _nLabelObjectID,
+    sal_uInt16 _nControlObjectID, const ::rtl::OUString& _rFieldPostfix, sal_uInt32 _nInventor, sal_uInt16 _nLabelObjectID,
     SdrPage* _pLabelPage, SdrPage* _pControlPage, SdrModel* _pModel, SdrUnoObj*& _rpLabel, SdrUnoObj*& _rpControl )
 {
     FmXFormView::createControlLabelPair(
