@@ -29,7 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_ucb.hxx"
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <vector>
 #include <string.h>
 #include "osl/diagnose.h"
@@ -39,7 +39,16 @@
 #include <ne_auth.h>
 #include <ne_redirect.h>
 #include <ne_ssl.h>
+
+#if NEON_VERSION < 0x0260
+// old neon versions forgot to set this
+extern "C" {
+#endif
 #include <ne_compress.h>
+#if NEON_VERSION < 0x0260
+}
+#endif
+
 #include "libxml/parser.h"
 #include "rtl/ustrbuf.hxx"
 #include "comphelper/sequence.hxx"
@@ -109,7 +118,7 @@ struct hashPtr
     }
 };
 
-typedef std::hash_map
+typedef boost::unordered_map
 <
     ne_request*,
     RequestData,
@@ -128,15 +137,15 @@ static sal_uInt16 makeStatusCode( const rtl::OUString & rStatusText )
 
     if ( rStatusText.getLength() < 3 )
     {
-        OSL_ENSURE(
-            sal_False, "makeStatusCode - status text string to short!" );
+        OSL_FAIL(
+            "makeStatusCode - status text string to short!" );
         return 0;
     }
 
     sal_Int32 nPos = rStatusText.indexOf( ' ' );
     if ( nPos == -1 )
     {
-        OSL_ENSURE( sal_False, "makeStatusCode - wrong status text format!" );
+        OSL_FAIL( "makeStatusCode - wrong status text format!" );
         return 0;
     }
 
@@ -185,11 +194,7 @@ struct NeonRequestContext
 // A simple Neon response_block_reader for use with an XInputStream
 // -------------------------------------------------------------------
 
-#if NEON_VERSION >= 0x0250
 extern "C" int NeonSession_ResponseBlockReader(void * inUserData,
-#else
-extern "C" void NeonSession_ResponseBlockReader(void * inUserData,
-#endif
                                                const char * inBuf,
                                                size_t inLen )
 {
@@ -205,9 +210,7 @@ extern "C" void NeonSession_ResponseBlockReader(void * inUserData,
         if ( xInputStream.is() )
             xInputStream->AddToStream( inBuf, inLen );
     }
-#if NEON_VERSION >= 0x0250
     return 0;
-#endif
 }
 
 // -------------------------------------------------------------------
@@ -215,11 +218,7 @@ extern "C" void NeonSession_ResponseBlockReader(void * inUserData,
 // A simple Neon response_block_reader for use with an XOutputStream
 // -------------------------------------------------------------------
 
-#if NEON_VERSION >= 0x0250
 extern "C" int NeonSession_ResponseBlockWriter( void * inUserData,
-#else
-extern "C" void NeonSession_ResponseBlockWriter( void * inUserData,
-#endif
                                                 const char * inBuf,
                                                 size_t inLen )
 {
@@ -237,9 +236,7 @@ extern "C" void NeonSession_ResponseBlockWriter( void * inUserData,
             xOutputStream->writeBytes( aSeq );
         }
     }
-#if NEON_VERSION >= 0x0250
     return 0;
-#endif
 }
 
 // -------------------------------------------------------------------
@@ -332,8 +329,8 @@ extern "C" int NeonSession_NeonAuth( void *       inUserData,
         rtl::OUStringToOString( theUserName, RTL_TEXTENCODING_UTF8 ) );
     if ( aUser.getLength() > ( NE_ABUFSIZ - 1 ) )
     {
-        OSL_ENSURE(
-            sal_False, "NeonSession_NeonAuth - username to long!" );
+        OSL_FAIL(
+            "NeonSession_NeonAuth - username to long!" );
         return -1;
     }
 
@@ -341,8 +338,8 @@ extern "C" int NeonSession_NeonAuth( void *       inUserData,
         rtl::OUStringToOString( thePassWord, RTL_TEXTENCODING_UTF8 ) );
     if ( aPass.getLength() > ( NE_ABUFSIZ - 1 ) )
     {
-        OSL_ENSURE(
-            sal_False, "NeonSession_NeonAuth - password to long!" );
+        OSL_FAIL(
+            "NeonSession_NeonAuth - password to long!" );
         return -1;
     }
 
@@ -363,7 +360,7 @@ namespace {
     ::rtl::OUString GetHostnamePart( const ::rtl::OUString& _rRawString )
     {
         ::rtl::OUString sPart;
-        ::rtl::OUString sPartId = ::rtl::OUString::createFromAscii( "CN=" );
+        ::rtl::OUString sPartId(RTL_CONSTASCII_USTRINGPARAM("CN="));
         sal_Int32 nContStart = _rRawString.indexOf( sPartId );
         if ( nContStart != -1 )
         {
@@ -390,8 +387,8 @@ extern "C" int NeonSession_CertificationNotify( void *userdata,
         xCertificateContainer
             = uno::Reference< security::XCertificateContainer >(
                 pSession->getMSF()->createInstance(
-                    rtl::OUString::createFromAscii(
-                        "com.sun.star.security.CertificateContainer" ) ),
+                    rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                        "com.sun.star.security.CertificateContainer" )) ),
                 uno::UNO_QUERY );
     }
     catch ( uno::Exception const & )
@@ -423,7 +420,7 @@ extern "C" int NeonSession_CertificationNotify( void *userdata,
     {
         xSEInitializer = uno::Reference< xml::crypto::XSEInitializer >(
             pSession->getMSF()->createInstance(
-                rtl::OUString::createFromAscii( SEINITIALIZER_COMPONENT ) ),
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SEINITIALIZER_COMPONENT )) ),
             uno::UNO_QUERY );
     }
     catch ( uno::Exception const & )
@@ -817,10 +814,13 @@ void NeonSession::Init()
         ne_redirect_register( m_pHttpSession );
 
         // authentication callbacks.
-        ne_add_server_auth(
-            m_pHttpSession, NE_AUTH_ALL, NeonSession_NeonAuth, this );
-        ne_add_proxy_auth(
-            m_pHttpSession, NE_AUTH_ALL, NeonSession_NeonAuth, this );
+#if NEON_VERSION >= 0x0260
+        ne_add_server_auth( m_pHttpSession, NE_AUTH_ALL, NeonSession_NeonAuth, this );
+        ne_add_proxy_auth ( m_pHttpSession, NE_AUTH_ALL, NeonSession_NeonAuth, this );
+#else
+        ne_set_server_auth( m_pHttpSession, NeonSession_NeonAuth, this );
+        ne_set_proxy_auth ( m_pHttpSession, NeonSession_NeonAuth, this );
+#endif
     }
 }
 
@@ -1014,8 +1014,7 @@ void NeonSession::PROPPATCH( const rtl::OUString & inPath,
                 }
                 else
                 {
-                    OSL_ENSURE( sal_False,
-                                "NeonSession::PROPPATCH - unsupported type!" );
+                    OSL_FAIL( "NeonSession::PROPPATCH - unsupported type!" );
                     // Error!
                     pItems[ n ].value = 0;
                     theRetVal = NE_ERROR;
@@ -1922,14 +1921,7 @@ int NeonSession::GET( ne_session * sess,
     //struct get_context ctx;
     ne_request * req = ne_request_create( sess, "GET", uri );
     int ret;
-    void *cursor = NULL;
-    const char *name, *value;
 
-#if NEON_VERSION < 0x0250
-    if ( getheaders )
-        ne_add_response_header_catcher(
-            req, runResponseHeaderHandler, userdata );
-#endif
     ne_decompress * dc
         = ne_decompress_reader( req, ne_accept_2xx, reader, userdata );
 
@@ -1938,9 +1930,10 @@ int NeonSession::GET( ne_session * sess,
         ret = ne_request_dispatch( req );
     }
 
-#if NEON_VERSION >= 0x0250
     if ( getheaders )
     {
+        void *cursor = NULL;
+        const char *name, *value;
         while ( ( cursor = ne_response_header_iterate(
                                req, cursor, &name, &value ) ) != NULL )
         {
@@ -1950,7 +1943,7 @@ int NeonSession::GET( ne_session * sess,
             runResponseHeaderHandler(userdata, buffer);
         }
     }
-#endif
+
     if ( ret == NE_OK && ne_get_status( req )->klass != 2 )
         ret = NE_ERROR;
 
@@ -2147,7 +2140,7 @@ NeonSession::isDomainMatch( rtl::OUString certHostName )
     if (hostName.equalsIgnoreAsciiCase( certHostName ) )
         return sal_True;
 
-    if ( 0 == certHostName.indexOf( rtl::OUString::createFromAscii( "*" ) ) &&
+    if ( 0 == certHostName.indexOf( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("*")) ) &&
          hostName.getLength() >= certHostName.getLength()  )
     {
         rtl::OUString cmpStr = certHostName.copy( 1 );
