@@ -50,14 +50,14 @@
 
 namespace treeview {
 
-
+    
     class TVDom
     {
         friend class TVChildTarget;
         friend class TVRead;
-
+    
     public:
-
+        
         TVDom( TVDom* arent = 0 )
             : kind( other ),
               parent( arent ),
@@ -145,27 +145,27 @@ namespace treeview {
                     if ( len != 0 )
                         break;
                 }
-
+                
                 rtl::OUStringBuffer strBuff( 22 + len + id.getLength() );
                 strBuff.appendAscii(
                                     "vnd.sun.star.help://"
                                     ).append(id);
-
+                
                 targetURL = strBuff.makeStringAndClear();
             }
-
+            
             return targetURL;
         }
-
+    
     private:
-
+    
         Kind   kind;
         rtl::OUString  application;
         rtl::OUString  title;
         rtl::OUString  id;
         rtl::OUString  anchor;
         rtl::OUString  targetURL;
-
+        
         TVDom *parent;
         std::vector< TVDom* > childs;
     };
@@ -186,11 +186,11 @@ using namespace com::sun::star::deployment;
 
 
 ConfigData::ConfigData()
-    : prodName( rtl::OUString::createFromAscii( "%PRODUCTNAME" ) ),
-      prodVersion( rtl::OUString::createFromAscii( "%PRODUCTVERSION" ) ),
-      vendName( rtl::OUString::createFromAscii( "%VENDORNAME" ) ),
-      vendVersion( rtl::OUString::createFromAscii( "%VENDORVERSION" ) ),
-      vendShort( rtl::OUString::createFromAscii( "%VENDORSHORT" ) )
+    : prodName(RTL_CONSTASCII_USTRINGPARAM("%PRODUCTNAME")),
+      prodVersion(RTL_CONSTASCII_USTRINGPARAM("%PRODUCTVERSION")),
+      vendName(RTL_CONSTASCII_USTRINGPARAM("%VENDORNAME")),
+      vendVersion(RTL_CONSTASCII_USTRINGPARAM("%VENDORVERSION")),
+      vendShort(RTL_CONSTASCII_USTRINGPARAM("%VENDORSHORT"))
 {
 }
 
@@ -199,7 +199,7 @@ void SAL_CALL ConfigData::replaceName( rtl::OUString& oustring ) const
     sal_Int32 idx = -1,k = 0,off;
     bool cap = false;
     rtl::OUStringBuffer aStrBuf( 0 );
-
+    
     while( ( idx = oustring.indexOf( sal_Unicode('%'),++idx ) ) != -1 )
     {
         if( oustring.indexOf( prodName,idx ) == idx )
@@ -214,7 +214,7 @@ void SAL_CALL ConfigData::replaceName( rtl::OUString& oustring ) const
             off = VENDORSHORT;
         else
             off = -1;
-
+        
         if( off != -1 )
         {
             if( ! cap )
@@ -222,13 +222,13 @@ void SAL_CALL ConfigData::replaceName( rtl::OUString& oustring ) const
                 cap = true;
                 aStrBuf.ensureCapacity( 256 );
             }
-
+            
             aStrBuf.append( &oustring.getStr()[k],idx - k );
             aStrBuf.append( m_vReplacement[off] );
             k = idx + m_vAdd[off];
         }
     }
-
+    
     if( cap )
     {
         if( k < oustring.getLength() )
@@ -274,7 +274,7 @@ TVBase::queryInterface(
                                      SAL_STATIC_CAST( XHierarchicalNameAccess*, this ),
                                      SAL_STATIC_CAST( XChangesNotifier*, this ),
                                      SAL_STATIC_CAST( XComponent*, this ) );
-
+    
     return aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType );
 }
 
@@ -302,14 +302,14 @@ TVRead::TVRead( const ConfigData& configData,TVDom* tvDom )
 {
     if( ! tvDom )
         return;
-
+    
     Title = tvDom->title;
     configData.replaceName( Title );
     if( tvDom->isLeaf() )
     {
         TargetURL = ( tvDom->getTargetURL() + configData.appendix );
         if( tvDom->anchor.getLength() )
-            TargetURL += ( rtl::OUString::createFromAscii( "#" ) +
+            TargetURL += ( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "#" )) +
                            tvDom->anchor );
     }
     else
@@ -364,9 +364,9 @@ TVRead::getElementNames( )
 {
     Sequence< rtl::OUString > seq( 3 );
 
-    seq[0] = rtl::OUString::createFromAscii( "Title" );
-    seq[1] = rtl::OUString::createFromAscii( "TargetURL" );
-    seq[2] = rtl::OUString::createFromAscii( "Children" );
+    seq[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Title" ));
+    seq[1] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "TargetURL" ));
+    seq[2] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Children" ));
 
     return seq;
 }
@@ -381,7 +381,7 @@ TVRead::hasByName( const rtl::OUString& aName )
         aName.compareToAscii( "TargetURL" ) == 0    ||
         aName.compareToAscii( "Children" ) == 0 )
         return true;
-
+    
     return false;
 }
 
@@ -395,11 +395,11 @@ TVRead::getByHierarchicalName( const rtl::OUString& aName )
 {
     sal_Int32 idx;
     rtl::OUString name( aName );
-
+    
     if( ( idx = name.indexOf( sal_Unicode( '/' ) ) ) != -1  &&
         name.copy( 0,idx ).compareToAscii( "Children" ) == 0 )
         return Children->getByHierarchicalName( name.copy( 1 + idx ) );
-
+    
     return getByName( name );
 }
 
@@ -412,11 +412,11 @@ TVRead::hasByHierarchicalName( const rtl::OUString& aName )
 {
     sal_Int32 idx;
     rtl::OUString name( aName );
-
+    
        if( ( idx = name.indexOf( sal_Unicode( '/' ) ) ) != -1  &&
         name.copy( 0,idx ).compareToAscii( "Children" ) == 0 )
         return Children->hasByHierarchicalName( name.copy( 1 + idx ) );
-
+    
     return hasByName( name );
 }
 
@@ -444,14 +444,14 @@ extern "C" void start_handler(void *userData,
         kind = TVDom::tree_leaf;
     else
         return;
-
+    
     TVDom **tvDom = static_cast< TVDom** >( userData );
     TVDom  *p;
     p = *tvDom;
 
     *tvDom = p->newChild();
     p = *tvDom;
-
+    
     p->setKind( kind );
     while( *atts )
     {
@@ -463,7 +463,7 @@ extern "C" void start_handler(void *userData,
             p->setId( *(atts+1) );
         else if( strcmp( *atts,"anchor" ) == 0 )
             p->setAnchor( *(atts+1) );
-
+        
         atts+=2;
     }
 }
@@ -520,10 +520,10 @@ TVChildTarget::TVChildTarget( const Reference< XMultiServiceFactory >& xMSF )
         len = configData.vFileLen[--j];
         char* s = new char[ int(len) ];  // the buffer to hold the installed files
         osl::File aFile( configData.vFileURL[j] );
-        aFile.open( OpenFlag_Read );
+        aFile.open( osl_File_OpenFlag_Read );
         aFile.read( s,len,ret );
         aFile.close();
-
+        
         XML_Parser parser = XML_ParserCreate( 0 );
         XML_SetElementHandler( parser,
                                start_handler,
@@ -581,7 +581,7 @@ TVChildTarget::getElementNames( )
     Sequence< rtl::OUString > seq( Elements.size() );
     for( unsigned i = 0; i < Elements.size(); ++i )
         seq[i] = rtl::OUString::valueOf( sal_Int32( 1+i ) );
-
+    
     return seq;
 }
 
@@ -668,7 +668,7 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     rtl::OUString instPath( getKey( xHierAccess,"Path/Current/Help" ) );
     if( ! instPath.getLength() )
       // try to determine path from default
-      instPath = rtl::OUString::createFromAscii( "$(instpath)/help" );
+      instPath = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "$(instpath)/help" ));
 
     // replace anything like $(instpath);
     subst( xSMgr,instPath );
@@ -689,21 +689,21 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     try
     {
         uno::Reference< lang::XMultiServiceFactory > xConfigProvider(
-              xSMgr ->createInstance(::rtl::OUString::createFromAscii("com.sun.star.configuration.ConfigurationProvider")), uno::UNO_QUERY_THROW);
+              xSMgr ->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.configuration.ConfigurationProvider"))), uno::UNO_QUERY_THROW);
 
         uno::Sequence < uno::Any > lParams(1);
         beans::PropertyValue                       aParam ;
-        aParam.Name    = ::rtl::OUString::createFromAscii("nodepath");
-        aParam.Value <<= ::rtl::OUString::createFromAscii("/org.openoffice.Setup/Product");
+        aParam.Name    = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("nodepath"));
+        aParam.Value <<= ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/org.openoffice.Setup/Product"));
         lParams[0] = uno::makeAny(aParam);
 
         // open it
         uno::Reference< uno::XInterface > xCFG( xConfigProvider->createInstanceWithArguments(
-                    ::rtl::OUString::createFromAscii("com.sun.star.configuration.ConfigurationAccess"),
+                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.configuration.ConfigurationAccess")),
                     lParams) );
 
         uno::Reference< container::XNameAccess > xDirectAccess(xCFG, uno::UNO_QUERY);
-        uno::Any aRet = xDirectAccess->getByName(::rtl::OUString::createFromAscii("ooSetupExtension"));
+        uno::Any aRet = xDirectAccess->getByName(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ooSetupExtension")));
 
         aRet >>= setupextension;
     }
@@ -712,7 +712,7 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     }
 
     rtl::OUString productVersion( setupversion +
-                                  rtl::OUString::createFromAscii( " " ) +
+                                  rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( " " )) +
                                   setupextension );
     rtl::OUString locale( getKey( xHierAccess,"L10N/ooLocale" ) );
 
@@ -722,7 +722,7 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     osl::FileBase::RC errFile = osl::FileBase::getFileURLFromSystemPath( instPath,url );
     if( errFile != osl::FileBase::E_None ) return configData;
     if( url.lastIndexOf( sal_Unicode( '/' ) ) != url.getLength() - 1 )
-        url += rtl::OUString::createFromAscii( "/" );
+        url += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "/" ));
     rtl::OUString ret;
     sal_Int32 idx;
     osl::DirectoryItem aDirItem;
@@ -735,11 +735,11 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
         ret = locale.copy( 0,idx );
     else
         {
-        locale = rtl::OUString::createFromAscii( "en-US" );
-        ret = rtl::OUString::createFromAscii("en");
+        locale = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "en-US" ));
+        ret = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("en"));
         }
     url = url + ret;
-
+    
     // first of all, try do determine whether there are any *.tree files present
 
     // Start with extensions to set them at the end of the list
@@ -783,9 +783,15 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
                 rtl::OUString baseName = aFileName.copy(0,idx_).toAsciiLowerCase();
                 if(! showBasic && baseName.compareToAscii("sbasic") == 0 )
                   continue;
-
-                configData.vFileLen.push_back( aFileStatus.getFileSize() );
-                configData.vFileURL.push_back( aFileUrl );
+                osl::File aFile( aFileUrl );
+                if( osl::FileBase::E_None == aFile.open( osl_File_OpenFlag_Read ) )
+                {
+                    sal_uInt64 nSize;
+                    aFile.getSize( nSize );
+                    configData.vFileLen.push_back( aFileStatus.getFileSize() );
+                    configData.vFileURL.push_back( aFileUrl );
+                    aFile.close();
+                }
               }
           }
         aDirectory.close();
@@ -803,11 +809,11 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
        configData.system = system;
     configData.locale = locale;
     configData.appendix =
-        rtl::OUString::createFromAscii( "?Language=" ) +
+        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "?Language=" )) +
         configData.locale +
-        rtl::OUString::createFromAscii( "&System=" ) +
+        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "&System=" )) +
         configData.system +
-        rtl::OUString::createFromAscii( "&UseDB=no" ) ;
+        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "&UseDB=no" )) ;
 
     return configData;
 }
@@ -829,7 +835,7 @@ TVChildTarget::getConfiguration(const Reference< XMultiServiceFactory >& m_xSMgr
         try
         {
             rtl::OUString sProviderService =
-                rtl::OUString::createFromAscii( "com.sun.star.configuration.ConfigurationProvider" );
+                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationProvider" ));
             sProvider =
                 Reference< XMultiServiceFactory >(
                     m_xSMgr->createInstance( sProviderService ),
@@ -840,7 +846,7 @@ TVChildTarget::getConfiguration(const Reference< XMultiServiceFactory >& m_xSMgr
             OSL_ENSURE( sProvider.is(),"cant instantiate configuration" );
         }
     }
-
+    
     return sProvider;
 }
 
@@ -856,7 +862,7 @@ TVChildTarget::getHierAccess( const Reference< XMultiServiceFactory >& sProvider
     {
         Sequence< Any > seq(1);
         rtl::OUString sReaderService =
-            rtl::OUString::createFromAscii( "com.sun.star.configuration.ConfigurationAccess" );
+            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationAccess" ));
 
         seq[0] <<= rtl::OUString::createFromAscii( file );
 
@@ -871,7 +877,7 @@ TVChildTarget::getHierAccess( const Reference< XMultiServiceFactory >& sProvider
         {
         }
     }
-
+    
     return xHierAccess;
 }
 
@@ -933,7 +939,7 @@ void TVChildTarget::subst( const Reference< XMultiServiceFactory >& m_xSMgr,
         {
             xCfgMgr =
                 Reference< XConfigManager >(
-                    m_xSMgr->createInstance( rtl::OUString::createFromAscii( "com.sun.star.config.SpecialConfigManager" ) ),
+                    m_xSMgr->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.config.SpecialConfigManager" )) ),
                     UNO_QUERY );
         }
         catch( const com::sun::star::uno::Exception& )
@@ -941,9 +947,9 @@ void TVChildTarget::subst( const Reference< XMultiServiceFactory >& m_xSMgr,
             OSL_ENSURE( xCfgMgr.is()," cant instantiate the special config manager " );
         }
     }
-
+    
     OSL_ENSURE( xCfgMgr.is(), "specialconfigmanager not found\n" );
-
+    
     if( xCfgMgr.is() )
         instpath = xCfgMgr->substituteVariables( instpath );
 }
@@ -952,9 +958,9 @@ void TVChildTarget::subst( const Reference< XMultiServiceFactory >& m_xSMgr,
 //===================================================================
 // class ExtensionIteratorBase
 
-static rtl::OUString aSlash( rtl::OUString::createFromAscii( "/" ) );
-static rtl::OUString aHelpFilesBaseName( rtl::OUString::createFromAscii( "help" ) );
-static rtl::OUString aHelpMediaType( rtl::OUString::createFromAscii( "application/vnd.sun.star.help" ) );
+static rtl::OUString aSlash(RTL_CONSTASCII_USTRINGPARAM("/"));
+static rtl::OUString aHelpFilesBaseName(RTL_CONSTASCII_USTRINGPARAM("help"));
+static rtl::OUString aHelpMediaType(RTL_CONSTASCII_USTRINGPARAM( "application/vnd.sun.star.help"));
 
 ExtensionIteratorBase::ExtensionIteratorBase( const rtl::OUString& aLanguage )
         : m_eState( USER_EXTENSIONS )
@@ -977,13 +983,13 @@ void ExtensionIteratorBase::init()
     if( !m_xContext.is() )
     {
         throw RuntimeException(
-            ::rtl::OUString::createFromAscii( "ExtensionIteratorBase::init(), no XComponentContext" ),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "ExtensionIteratorBase::init(), no XComponentContext" )),
             Reference< XInterface >() );
     }
 
     Reference< XMultiComponentFactory > xSMgr( m_xContext->getServiceManager(), UNO_QUERY );
     m_xSFA = Reference< ucb::XSimpleFileAccess >(
-        xSMgr->createInstanceWithContext( rtl::OUString::createFromAscii( "com.sun.star.ucb.SimpleFileAccess" ),
+        xSMgr->createInstanceWithContext( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.ucb.SimpleFileAccess" )),
         m_xContext ), UNO_QUERY_THROW );
 
     m_bUserPackagesLoaded = false;
@@ -1054,7 +1060,7 @@ Reference< deployment::XPackage > ExtensionIteratorBase::implGetNextUserHelpPack
     if( !m_bUserPackagesLoaded )
     {
         Reference< XPackageManager > xUserManager =
-            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString::createFromAscii("user") );
+            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("user")) );
         m_aUserPackagesSeq = xUserManager->getDeployedPackages
             ( Reference< task::XAbortChannel >(), Reference< ucb::XCommandEnvironment >() );
 
@@ -1084,7 +1090,7 @@ Reference< deployment::XPackage > ExtensionIteratorBase::implGetNextSharedHelpPa
     if( !m_bSharedPackagesLoaded )
     {
         Reference< XPackageManager > xSharedManager =
-            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString::createFromAscii("shared") );
+            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("shared")) );
         m_aSharedPackagesSeq = xSharedManager->getDeployedPackages
             ( Reference< task::XAbortChannel >(), Reference< ucb::XCommandEnvironment >() );
 
@@ -1114,7 +1120,7 @@ Reference< deployment::XPackage > ExtensionIteratorBase::implGetNextBundledHelpP
     if( !m_bBundledPackagesLoaded )
     {
         Reference< XPackageManager > xBundledManager =
-            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString::createFromAscii("bundled") );
+            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("bundled")) );
         m_aBundledPackagesSeq = xBundledManager->getDeployedPackages
             ( Reference< task::XAbortChannel >(), Reference< ucb::XCommandEnvironment >() );
 
@@ -1219,7 +1225,7 @@ rtl::OUString TreeFileIterator::nextTreeFile( sal_Int32& rnFileSize )
             }
 
         case END_REACHED:
-                OSL_ENSURE( false, "DataBaseIterator::nextTreeFile(): Invalid case END_REACHED" );
+                OSL_FAIL( "DataBaseIterator::nextTreeFile(): Invalid case END_REACHED" );
                 break;
         }
     }
@@ -1239,18 +1245,18 @@ rtl::OUString TreeFileIterator::expandURL( const rtl::OUString& aURL )
         Reference< XMultiComponentFactory > xSMgr( m_xContext->getServiceManager(), UNO_QUERY );
 
         xFac = Reference< uri::XUriReferenceFactory >(
-            xSMgr->createInstanceWithContext( rtl::OUString::createFromAscii(
-            "com.sun.star.uri.UriReferenceFactory"), m_xContext ) , UNO_QUERY );
+            xSMgr->createInstanceWithContext( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+            "com.sun.star.uri.UriReferenceFactory")), m_xContext ) , UNO_QUERY );
         if( !xFac.is() )
         {
             throw RuntimeException(
-                ::rtl::OUString::createFromAscii( "Databases::expand(), could not instatiate UriReferenceFactory." ),
+                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Databases::expand(), could not instatiate UriReferenceFactory." )),
                 Reference< XInterface >() );
         }
 
         xMacroExpander = Reference< util::XMacroExpander >(
             m_xContext->getValueByName(
-            ::rtl::OUString::createFromAscii( "/singletons/com.sun.star.util.theMacroExpander" ) ),
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "/singletons/com.sun.star.util.theMacroExpander" )) ),
             UNO_QUERY_THROW );
      }
 
