@@ -409,13 +409,12 @@ void XMLTextExportPropertySetMapper::ContextFilter(
     XMLPropertyState* pHoriOrientRelState = NULL;
     XMLPropertyState* pHoriOrientRelFrameState = NULL;
     XMLPropertyState* pHoriOrientMirrorState = NULL;
-    // --> OD 2004-08-09 #i28749# - horizontal position and relation for shapes
+    // Horizontal position and relation for shapes (#i28749#)
     XMLPropertyState* pShapeHoriOrientState = NULL;
     XMLPropertyState* pShapeHoriOrientMirroredState = NULL;
     XMLPropertyState* pShapeHoriOrientRelState = NULL;
     XMLPropertyState* pShapeHoriOrientRelFrameState = NULL;
     XMLPropertyState* pShapeHoriOrientMirrorState = NULL;
-    // <--
 
     // vertical position and relation
     XMLPropertyState* pVertOrientState = NULL;
@@ -425,13 +424,12 @@ void XMLTextExportPropertySetMapper::ContextFilter(
     XMLPropertyState* pVertOrientRelFrameState = NULL;
     XMLPropertyState* pVertOrientRelAsCharState = NULL;
 
-    // --> OD 2004-08-09 #i28749# - vertical position and relation for shapes
+    // Vertical position and relation for shapes (#i28749#)
     XMLPropertyState* pShapeVertOrientState = NULL;
     XMLPropertyState* pShapeVertOrientAtCharState = NULL;
     XMLPropertyState* pShapeVertOrientRelState = NULL;
     XMLPropertyState* pShapeVertOrientRelPageState = NULL;
     XMLPropertyState* pShapeVertOrientRelFrameState = NULL;
-    // <--
 
     // filter underline color
     XMLPropertyState* pUnderlineState = NULL;
@@ -522,7 +520,7 @@ void XMLTextExportPropertySetMapper::ContextFilter(
         case CTF_VERTICALREL_FRAME:  	pVertOrientRelFrameState = propertie; bNeedsAnchor = sal_True; break;
         case CTF_VERTICALREL_ASCHAR: 	pVertOrientRelAsCharState = propertie; bNeedsAnchor = sal_True; break;
 
-        // --> OD 2004-08-09 #i28749# - handle new CTFs for shape positioning properties
+        // Handle new CTFs for shape positioning properties (#i28749#)
         case CTF_SHAPE_HORIZONTALPOS:             pShapeHoriOrientState = propertie; bNeedsAnchor = sal_True; break;
         case CTF_SHAPE_HORIZONTALPOS_MIRRORED:    pShapeHoriOrientMirroredState = propertie; bNeedsAnchor = sal_True; break;
         case CTF_SHAPE_HORIZONTALREL:             pShapeHoriOrientRelState = propertie; bNeedsAnchor = sal_True; break;
@@ -533,8 +531,6 @@ void XMLTextExportPropertySetMapper::ContextFilter(
         case CTF_SHAPE_VERTICALREL:           pShapeVertOrientRelState = propertie; bNeedsAnchor = sal_True; break;
         case CTF_SHAPE_VERTICALREL_PAGE:      pShapeVertOrientRelPageState = propertie; bNeedsAnchor = sal_True; break;
         case CTF_SHAPE_VERTICALREL_FRAME:     pShapeVertOrientRelFrameState = propertie; bNeedsAnchor = sal_True; break;
-        // <--
-
         case CTF_FONTNAME: 				pFontNameState = propertie; break;
         case CTF_FONTFAMILYNAME: 		pFontFamilyNameState = propertie; break;
         case CTF_FONTSTYLENAME: 		pFontStyleNameState = propertie; break;
@@ -702,12 +698,15 @@ void XMLTextExportPropertySetMapper::ContextFilter(
             if( aLeft.Color == aRight.Color && aLeft.InnerLineWidth == aRight.InnerLineWidth &&
                 aLeft.OuterLineWidth == aRight.OuterLineWidth && aLeft.LineDistance == aRight.LineDistance &&
                 aLeft.LineStyle == aRight.LineStyle &&
+                aLeft.LineWidth == aRight.LineWidth &&
                 aLeft.Color == aTop.Color && aLeft.InnerLineWidth == aTop.InnerLineWidth &&
                 aLeft.OuterLineWidth == aTop.OuterLineWidth && aLeft.LineDistance == aTop.LineDistance &&
                 aLeft.LineStyle == aTop.LineStyle &&
+                aLeft.LineWidth == aTop.LineWidth &&
                 aLeft.Color == aBottom.Color && aLeft.InnerLineWidth == aBottom.InnerLineWidth &&
                 aLeft.OuterLineWidth == aBottom.OuterLineWidth && aLeft.LineDistance == aBottom.LineDistance &&
-                aLeft.LineStyle == aBottom.LineStyle )
+                aLeft.LineStyle == aBottom.LineStyle &&
+                aLeft.LineWidth == aBottom.LineWidth )
             {
                 pLeftBorderWidthState->mnIndex = -1;
                 pLeftBorderWidthState->maValue.clear();
@@ -778,11 +777,14 @@ void XMLTextExportPropertySetMapper::ContextFilter(
             if( aLeft.Color == aRight.Color && aLeft.InnerLineWidth == aRight.InnerLineWidth &&
                 aLeft.OuterLineWidth == aRight.OuterLineWidth && aLeft.LineDistance == aRight.LineDistance &&
                 aLeft.LineStyle == aRight.LineStyle &&
+                aLeft.LineWidth == aRight.LineWidth &&
                 aLeft.Color == aTop.Color && aLeft.InnerLineWidth == aTop.InnerLineWidth &&
                 aLeft.OuterLineWidth == aTop.OuterLineWidth && aLeft.LineDistance == aTop.LineDistance &&
                 aLeft.LineStyle == aTop.LineStyle  &&
+                aLeft.LineWidth == aTop.LineWidth  &&
                 aLeft.Color == aBottom.Color && aLeft.InnerLineWidth == aBottom.InnerLineWidth &&
                 aLeft.OuterLineWidth == aBottom.OuterLineWidth && aLeft.LineDistance == aBottom.LineDistance &&
+                aLeft.LineWidth == aBottom.LineWidth &&
                 aLeft.LineStyle == aBottom.LineStyle )
             {
                 pLeftBorderState->mnIndex = -1;
@@ -933,7 +935,7 @@ void XMLTextExportPropertySetMapper::ContextFilter(
             pVertOrientRelAsCharState->mnIndex = -1;
     }
 
-    // --> OD 2004-08-09 #i28749# - states for shape positioning properties
+    // States for shape positioning properties (#i28749#)
     if ( eAnchor != TextContentAnchorType_AS_CHARACTER &&
          ( GetExport().getExportFlags() & EXPORT_OASIS ) == 0 )
     {
@@ -992,7 +994,6 @@ void XMLTextExportPropertySetMapper::ContextFilter(
         if( pShapeVertOrientRelFrameState && TextContentAnchorType_AT_FRAME != eAnchor )
             pShapeVertOrientRelFrameState->mnIndex = -1;
     }
-    // <--
 
     // list style name: remove list style if it is the default outline style
     if( pListStyleName != NULL )
